# -*- coding: utf-8 -*-
#
# :description: Django reusable application to manage Dial code of Countries
#
# :copyright: (c) 2011-2014 Areski Belaid and individual contributors,
#                 All rights reserved.
# :license:   MIT, see MIT-LICENSE.txt for more details.
#

__version__ = '0.6.4'  # edit also docs/source/conf.py and update requirements.txt
__author__ = "Arezqui Belaid"
__contact__ = "areski@gmail.com"
__homepage__ = "http://www.areskibelaid.com"
__docformat__ = "restructuredtext"

default_app_config = 'country_dialcode.apps.CountryDialcodeConfig'
