INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1, 'USA', 225, 'USA_Carrier', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(15, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(16, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(17, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(20, 'Egypt', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27, 'South Africa', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(30, 'Greece', 83, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31, 'Netherlands', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32, 'Belgium', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33, 'France', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34, 'Spain', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(36, 'Hungary', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39, 'Italy', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(40, 'Romania', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41, 'Switzerland', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43, 'Austria', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44, 'United Kingdom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45, 'Denmark', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46, 'Sweden', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(47, 'Norway', 160, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48, 'Poland', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49, 'Germany', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51, 'Peru', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(52, 'Mexico', 138, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(53, 'Cuba', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(54, 'Argentina', 10, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55, 'Brazil', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(56, 'Falkland Islands Mobile', 69, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57, 'Colombia', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(58, 'Venezuela', 230, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(60, 'Malaysia', 129, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61, 'Australia', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(62, 'Indonesia', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(63, 'Philippines', 169, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(64, 'New Zealand', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(65, 'Singapore', 191, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(66, 'Thailand', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(70, 'Kazakstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(71, 'Kazakstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(72, 'Kazakstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(75, 'Kazakstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(76, 'Kazakstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(79, 'Russian Federation Mobile', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(81, 'Japan', 107, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(82, 'South Korea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84, 'Viet Nam', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(86, 'China', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(90, 'Turkey', 217, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(91, 'India', 99, 'India', 2);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(92, 'Pakistan', 162, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(93, 'Afghanistan', 1, 'Afghanistan', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(94, 'Sri Lanka', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(95, 'Myanmar', 146, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(98, 'Iran', 101, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(202, 'Egypt Cairo', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212, 'Morocco', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(213, 'Algeria', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(216, 'Tunisia', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(218, 'Libya', 121, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(220, 'Gambia', 78, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(221, 'Senegal', 188, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(222, 'Mauritania', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(223, 'Mali', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(224, 'Guinea', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(225, 'Ivory Coast', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(226, 'Burkina Faso', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(227, 'Niger', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(228, 'Togo', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(229, 'Benin', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230, 'Mauritius', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(231, 'Liberia', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(232, 'Sierra Leone', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(233, 'Ghana', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234, 'Nigeria', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(235, 'Chad', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(236, 'Central African Republic', 41, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(237, 'Cameroon', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(238, 'Cape Verde', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(239, 'Sao Tome and Principe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(240, 'Equatorial Guinea', 65, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(241, 'Gabon', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(242, 'Congo', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(243, 'Congo Democratic Republic', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(244, 'Angola', 6, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(245, 'Guinea-Bissau', 90, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(246, 'British Indian Ocean Territory', 31, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(247, 'Ascension Islands', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(248, 'Seychelles', 189, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(249, 'Sudan', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(250, 'Rwanda', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251, 'Ethiopia', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(252, 'Somalia', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(253, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(254, 'Kenya', 110, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(255, 'Tanzania', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(256, 'Uganda', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(257, 'Burundi', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(258, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(260, 'Zambia', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(261, 'Madagascar', 127, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(262, 'Reunion', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(263, 'Zimbabwe', 239, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(264, 'Namibia', 147, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(265, 'Malawi', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(266, 'Lesotho', 119, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(267, 'Botswana', 28, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(268, 'Swaziland', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(269, 'Comoros', 48, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(277, 'South Africa Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(290, 'St Helena', 179, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(291, 'Eritrea', 66, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(297, 'Aruba', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(298, 'Faeroes Islands', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(299, 'Greenland', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(306, 'Greece Mobile', 83, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(316, 'Netherlands Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(322, 'Belgium Brussels', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(323, 'Belgium Antwerp', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336, 'France Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(337, 'France Mobile Other', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(339, 'France Personal', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(346, 'Spain Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(350, 'Gibraltar', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(351, 'Portugal', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352, 'Luxembourg', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(353, 'Ireland', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354, 'Iceland', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(355, 'Albania', 2, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(356, 'Malta', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(357, 'Cyprus', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(358, 'Finland', 72, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(359, 'Bulgaria', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(361, 'Hungary Budapest', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(370, 'Lithuania', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(371, 'Latvia', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372, 'Estonia', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373, 'Moldova', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(374, 'Armenia', 11, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(375, 'Belarus', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(376, 'Andorra', 5, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(377, 'Monaco', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(378, 'San Marino', 185, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(379, 'Vatican City', 94, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(380, 'Ukraine', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(381, 'Serbia and Montenegro', 253, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(382, 'Montenegro', 252, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(385, 'Croatia', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386, 'Slovenia', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(387, 'Bosnia-Herzegovina', 27, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(389, 'Macedonia', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(393, 'Italy Mobile', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(398, 'washrooms nincompoops syncopation', NULL, 'menswear''s whip roller''s', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(403, 'Romania [OLO]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(407, 'Romania Mobile', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(420, 'Czech Republic', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421, 'Slovak Republic', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(423, 'Liechtenstein', 122, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(431, 'Austria Vienna', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441, 'United Kingdom Landline', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442, 'United Kingdom Landline', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(443, 'United Kingdom Landline', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(448, 'United Kingdom Special-Rate', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(449, 'United Kingdom Premium-Rate', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(452, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(453, 'Denmark Copenhagen', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(474, 'Norway Mobile', 160, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(479, 'Norway Mobile', 160, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491, 'Germany Other Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(500, 'Falkland Islands', 69, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(501, 'Belize', 22, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(502, 'Guatemala', 88, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(503, 'El Salvador', 64, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504, 'Honduras', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(505, 'Nicaragua', 154, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(506, 'Costa Rica', 52, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507, 'Panama', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(508, 'St Pierre and Miquelon', 182, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509, 'Haiti', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(511, 'Peru Lima', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(519, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(521, 'Mexico Mobile', 138, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(525, 'Mexico Mexico City', 138, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(535, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(549, 'Argentina Mobile', 10, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(562, 'Chile Santiago', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(568, 'Chile Mobile', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(569, 'Chile Mobile', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(572, 'Colombia Cali', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(573, 'Colombia Mobile', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(574, 'Colombia Medellin', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(584, 'Venezuela Mobile', 230, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(590, 'Guadeloupe', 86, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(591, 'Bolivia', 26, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592, 'Guyana', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(593, 'Ecuador', 62, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(594, 'French Guiana', 74, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595, 'Paraguay', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(596, 'Martinique', 134, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(597, 'Suriname', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(598, 'Uruguay', 227, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599, 'Netherlands Antilles', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(601, 'Malaysia Mobile', 129, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(614, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(628, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(632, 'Philippines Manilla', 169, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(639, 'Philippines Mobile', 169, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(642, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(658, 'Singapore Mobile', 191, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(659, 'Singapore Mobile', 191, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(661, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(662, 'Thailand Bangkok', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(666, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(668, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(669, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(670, 'East Timor', 243, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(673, 'Brunei Darussalam', 32, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(674, 'Nauru', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675, 'Papua New Guinea', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(676, 'Tonga', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(677, 'Solomon Islands', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(678, 'Vanuatu', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(679, 'Fiji', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680, 'Palau', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(681, 'Wallis and Futuna', 234, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(682, 'Cook Islands', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(683, 'Niue', 157, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(684, 'American Samoa', 4, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(685, 'Samoa', 184, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(686, 'Kiribati', 111, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(687, 'New Caledonia', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(688, 'Tuvalu', 220, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(689, 'French Polynesia', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(690, 'Tokelau', 213, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(691, 'Micronesia', 139, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(692, 'Marshall Islands', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(701, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(702, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(703, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(704, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(705, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(706, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(707, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(708, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(709, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771, 'Kazakhstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772, 'Kazakhstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(773, 'Kazakstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(776, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(777, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(790, 'Russia Mobile', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(791, 'Russia Mobile', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(792, 'Russia Mobile', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(796, 'Russia Mobile', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(800, 'International Freephone', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(821, 'South Korea Mobile', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(850, 'North Korea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(852, 'Hong Kong', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(853, 'Macao', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(855, 'Cambodia', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(856, 'Laos', 116, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(880, 'Bangladesh', 18, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(886, 'Taiwan', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(905, 'Turkey Mobile', 217, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(919, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(923, 'Pakistan Mobile', 162, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(937, 'Afghanistan Mobile', 1, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(947, 'Sri Lanka Mobile', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(959, 'Myanmar Mobile', 146, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(960, 'Maldives', 130, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(961, 'Lebanon', 118, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(962, 'Jordan', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(963, 'Syrian Arab Republic', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(964, 'Iraq', 102, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965, 'Kuwait', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(966, 'Saudi Arabia', 187, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(967, 'Yemen', 236, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(968, 'Oman', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(970, 'Palestinian Territory', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(971, 'United Arab Emirates', 223, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(972, 'Israel', 104, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(973, 'Bahrain', 17, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(974, 'Qatar', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(975, 'Bhutan', 25, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(976, 'Mongolia', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(977, 'Nepal', 149, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(989, 'Iran Mobile', 101, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(992, 'Tajikistan', 208, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(993, 'Turkmenistan', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(994, 'Azerbaijan', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(995, 'Georgia', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996, 'Kyrgyzstan', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998, 'Uzbekistan', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1191, 'emerson urgently mutant''s', 131, 'keels punched dobbin''s', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1201, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1202, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1203, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1204, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1205, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1206, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1207, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1208, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1209, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1210, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1212, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1213, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1214, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1215, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1216, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1217, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1218, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1219, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1224, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1225, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1226, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1227, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1228, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1229, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1231, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1234, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1239, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1240, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242, 'Bahamas', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246, 'Barbados', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1248, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1250, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1251, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1252, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1253, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1254, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1256, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1260, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1262, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264, 'Anguilla', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1267, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268, 'Antigua and Barbuda', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1269, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1270, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1276, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1281, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1283, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284, 'British Virgin Islands', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1289, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1301, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1302, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1303, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1304, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1305, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1306, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1307, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1308, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1309, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1310, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1312, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1313, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1314, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1315, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1316, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1317, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1318, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1319, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1320, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1321, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1323, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1325, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1330, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1331, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1334, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1336, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1337, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1339, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340, 'US Virgin Islands', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1341, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345, 'Cayman Islands', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1347, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1351, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1352, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1360, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1361, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1369, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1380, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1385, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1386, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1401, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1402, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1403, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1404, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1405, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1406, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1407, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1408, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1409, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1410, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1412, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1413, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1414, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1415, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1416, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1417, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1418, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1419, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1423, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1424, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1425, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1430, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1432, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1434, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1435, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1438, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1440, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1441, 'Bermuda', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1442, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1443, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1445, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1447, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1450, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1456, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1464, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1469, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1470, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473, 'Grenada', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1475, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1478, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1479, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1480, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1484, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1500, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1501, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1502, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1503, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1504, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1505, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1506, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1507, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1508, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1509, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1510, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1512, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1513, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1514, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1515, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1516, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1517, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1518, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1519, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1520, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1530, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1540, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1541, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1551, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1555, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1557, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1559, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1561, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1562, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1563, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1564, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1567, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1570, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1571, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1573, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1574, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1575, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1580, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1581, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1585, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1586, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1587, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1600, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1601, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1602, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1603, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1604, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1605, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1606, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1607, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1608, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1609, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1610, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1612, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1613, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1614, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1615, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1616, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1617, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1618, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1619, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1620, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1623, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1626, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1627, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1628, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1630, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1631, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1636, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1641, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1646, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1647, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649, 'Turks and Caicos', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1650, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1651, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1657, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1659, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1660, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1661, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1662, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1664, 'Montserrat', 143, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1667, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1669, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670, 'Northern Mariana Islands', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1671, 'Guam', 87, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1678, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1679, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1681, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1682, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1684, 'American Samoa', 4, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1689, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1700, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1701, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1702, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1703, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1704, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1705, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1706, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1707, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1708, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1709, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1710, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1712, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1713, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1714, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1715, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1716, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1717, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1718, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1719, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1720, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1724, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1727, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1730, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1731, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1732, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1734, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1737, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1740, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1747, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1752, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1754, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1757, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758, 'St Lucia', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1760, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1762, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1763, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1764, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1765, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767, 'Dominica', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1769, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1770, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1772, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1773, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1774, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1775, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1778, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1779, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1780, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1781, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1785, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1786, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787, 'Puerto Rico', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1801, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1802, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1803, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1804, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1805, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1806, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1807, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1808, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809, 'Dominican Republic', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1810, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1812, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1813, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1814, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1815, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1816, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1817, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1818, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1819, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1828, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829, 'Dominican Republic', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1830, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1831, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1832, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1835, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1843, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1845, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1847, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1848, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1849, 'Dominican Republic', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1850, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1856, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1857, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1858, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1859, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1860, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1862, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1863, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1864, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1865, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1867, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868, 'Trinidad and Tobago', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869, 'St Kitts and Nevis', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1870, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1871, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1872, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876, 'Jamaica', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1878, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1901, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1902, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1903, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1904, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1905, 'Canada', 38, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1906, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1907, 'United States [ALASKA]', 244, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1908, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1909, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1910, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1912, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1913, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1914, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1915, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1916, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1917, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1918, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1919, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1920, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1925, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1928, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1931, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1935, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1936, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1937, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939, 'Puerto Rico', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1940, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1941, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1947, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1949, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1951, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1952, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1954, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1956, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1959, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1970, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1971, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1972, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1973, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1975, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1978, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1979, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1980, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1984, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1985, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1989, 'United States', 225, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2010, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2011, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2012, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2014, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2016, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2017, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2018, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2019, 'Egypt Mobile', 63, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2121, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2126, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2127, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2132, 'Algeria  Algiers', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2135, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2136, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2137, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2139, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2162, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2164, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2169, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2203, 'Gambia Mobile', 78, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2206, 'Gambia Mobile', 78, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2207, 'Gambia Mobile', 78, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2209, 'Gambia Mobile', 78, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2222, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2223, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2224, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2226, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2236, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2237, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2246, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2247, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2267, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2279, 'Niger Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2280, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2289, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2299, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2305, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2313, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2314, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2315, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2316, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2317, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2318, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2341, 'Nigeria Lagos', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2352, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2353, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2356, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2357, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2359, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2374, 'Cameroon Mobile', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2375, 'Cameroon Mobile', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2376, 'Cameroon Mobile', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2377, 'Cameroon Mobile', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2378, 'Cameroon Mobile', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2379, 'Cameroon Mobile', 37, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2389, 'Cape Verde Mobile', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2402, 'Equatorial Guinea Mobile', 65, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2405, 'Equatorial Guinea Mobile', 65, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2406, 'Equatorial Guinea Mobile', 65, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2407, 'Equatorial Guinea Mobile', 65, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2410, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2411, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2412, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2413, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2423, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2424, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2425, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2426, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2427, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2429, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2436, 'Congo (Democratic Republic of) Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2438, 'Congo (Democratic Republic of) Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2439, 'Congo (Democratic Republic of) Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2455, 'Guinea-Bissau Mobile', 90, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2456, 'Guinea-Bissau Mobile', 90, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2457, 'Guinea-Bissau Mobile', 90, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2471, 'Ascension Georgetown', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2475, 'Ascension Georgetown', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2476, 'Ascension Georgetown', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2477, 'Ascension Georgetown', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2478, 'Ascension Georgetown', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2479, 'Ascension Georgetown', 240, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2485, 'Seychelles Mobile', 189, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2487, 'Seychelles Mobile', 189, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2499, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2500, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2507, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2511, 'Ethiopia Addis Ababa', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2519, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2527, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2535, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2536, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2537, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2547, 'Kenya Mobile', 110, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2556, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2557, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2567, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2575, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2576, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2577, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2578, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2579, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2588, 'Mozambique Mobile', 145, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2609, 'Zambia Mobile', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2613, 'Madagascar Mobile', 127, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2615, 'Madagascar Pager', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2653, 'Malawi Mobile', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2654, 'Malawi Mobile', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2655, 'Malawi Mobile', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2658, 'Malawi Mobile', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2659, 'Malawi Mobile', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2665, 'Lesotho Mobile', 119, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2666, 'Lesotho Mobile', 119, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2668, 'Lesotho Mobile', 119, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2677, 'Botswana Mobile', 28, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2686, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2693, 'Comoros Mobile', 48, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2696, 'Mayotte', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2697, 'Comoros', 48, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2711, 'South Africa Johannesburg', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2770, 'South Africa Other Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2772, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2773, 'South Africa MTN Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2774, 'South Africa Other Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2776, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2777, 'South Africa Other Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2778, 'South Africa MTN Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2779, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2782, 'South Africa Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2783, 'South Africa Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2784, 'South Africa Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2785, 'South Africa Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2786, 'South Africa Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2901, 'St Helena', 179, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2902, 'St Helena', 179, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2903, 'Tristan da Cunha', 255, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2904, 'St Helena', 179, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2906, 'St Helena', 179, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2908, 'Tristan da Cunha', 255, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2917, 'Eritrea Mobile', 66, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2985, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2992, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2994, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2995, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3021, 'Greece Athens', 83, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3069, 'Greece Mobile', 83, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3188, 'Netherlands Non Geo', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3245, 'Belgium Mobile', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3247, 'Belgium Mobile', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3248, 'Belgium Mobile', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3249, 'Belgium Mobile', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3277, 'milieus enthralled futzing', 191, 'democritus remarks intermezzo', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3341, 'sump tisha tawdrier', 1, 'angelic user pyotr''s', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3361, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3362, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3366, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3367, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3368, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3385, 'France VoIP', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3387, 'France Personal', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3465, 'spain mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3519, 'Portugal Mobile', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3520, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3526, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3546, 'Iceland Mobile Other', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3547, 'Iceland Mobile Other', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3549, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3554, 'Albania Tirana', 2, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3567, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3569, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3579, 'Cyprus Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3584, 'Finland Mobile', 72, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3592, 'Bulgaria Sofia', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3620, 'Hungary Mobile', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3630, 'Hungary Mobile', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3631, 'Hungary Mobile', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3650, 'Hungary Mobile', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3660, 'Hungary Mobile', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3670, 'Hungary Mobile', 97, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3706, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3708, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3712, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725, 'Estonia Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3739, 'Moldova MBL OLD', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3747, 'Armenia Mobile', 11, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3749, 'Armenia Mobile', 11, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3763, 'Andorra Mobile', 5, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3764, 'Andorra Mobile', 5, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3766, 'Andorra Mobile', 5, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3774, 'Monaco Mobile', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3776, 'Monaco Mobile', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3783, 'San Marino Mobile', 185, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3786, 'San Marino Mobile', 185, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3787, 'San Marino [SPC]', 185, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3809, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3816, 'Serbia and Montenegro Mobile', 252, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3859, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3876, 'Bosnia-Herzegovina Mobile', 27, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3897, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3932, 'Italy Mobile Wind', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3933, 'Italy Mobile TIM', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3934, 'Italy Mobile Vodafone', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3936, 'Italy Mobile TIM', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3939, 'Italy Mobile H3G', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4072, 'Romania [Vodafone]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4073, 'Romania [Vodafone]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4074, 'Romania [Orange]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4075, 'Romania [Orange]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4076, 'Romania [Cosmote]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4078, 'Romania [Telemobil]', 176, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4120, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4174, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4176, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4177, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4178, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4179, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4186, 'Switzerland Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4202, 'Czech Prague', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4222, 'lounged silicone emailed', NULL, 'fewer particularity chechen''s', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4236, 'Liechtenstein Mobile', 122, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4237, 'Liechtenstein Mobile', 122, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4367, 'Austria Mobile Other', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4368, 'Austria Mobile Other', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4369, 'Austria Mobile Other', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4389, 'poke doughty backbite', 251, 'quashed navigator''s adversarial', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4420, 'London', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4456, 'UK g21 LICS', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470, 'United Kingdom Personal Number', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4471, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4472, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4473, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4474, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4475, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476, 'United Kingdom Pager', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479, 'United Kingdom Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4522, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4525, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4526, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4527, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4528, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4530, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4531, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4540, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4541, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4542, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4550, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4551, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4552, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4553, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4560, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4561, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4571, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4581, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4596, 'Denmark', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4597, 'Denmark', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4598, 'Denmark', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4599, 'Denmark', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4610, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4670, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4672, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4673, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4674, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4676, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4759, 'Norway Mobile', 160, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4822, 'Poland Warsaw', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4850, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4851, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4860, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4866, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4869, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4932, 'Germany Premium', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5005, 'Falkland Islands Mobile', 69, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5006, 'Falkland Islands Mobile', 69, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5016, 'Belize Mobile', 22, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5024, 'Guatemala Mobile', 88, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5025, 'Guatemala Mobile', 88, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5037, 'El Salvador Mobile', 64, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5038, 'El Salvador Mobile', 64, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5043, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5047, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5048, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5049, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5052, 'Nicaragua', 154, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5054, 'Nicaragua Mobile', 154, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5056, 'Nicaragua Mobile', 154, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5058, 'Nicaragua Mobile', 154, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5059, 'Nicaragua Mobile', 154, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5063, 'Costa Rica Mobile', 52, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5068, 'Costa Rica Mobile', 52, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5072, 'Panama City', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5076, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5092, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5093, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5094, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5095, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5096, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5097, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5098, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5118, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5119, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5202, 'tamara chaffs kislev''s', 19, 'eloquently armories zeppelin', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5233, 'Mexico [FIX2]', 138, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5255, 'Mexico [FIX2]', 138, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5281, 'Mexico [FIX2]', 138, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5321, 'Cuba Guantanamo Bay', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5352, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5353, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5358, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5399, 'Cuba Guantanamo Bay', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5411, 'Argentina Buenos Aires', 10, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5511, 'Brazil Sao Paulo', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5521, 'Brazil Rio de Janeiro', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5561, 'Brazil Brasilia', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5712, 'Colombia Bogota', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5713, 'Colombia Bogota', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5714, 'Colombia Bogota', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5715, 'Colombia Bogota', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5716, 'Colombia Bogota', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5717, 'Colombia Bogota', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5763, 'Colombia Pereira', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5812, 'Venezuela Mobile', 230, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5911, 'Bolivia Mobile', 26, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5912, 'Bolivia La Paz', 26, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5917, 'Bolivia Mobile', 26, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5926, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5928, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5938, 'Ecuador Mobile', 62, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5939, 'Ecuador Mobile', 62, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5946, 'French Guiana Mobile', 74, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5959, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5977, 'Suriname Mobile', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5978, 'Suriname Mobile', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5979, 'Suriname Mobile', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5989, 'Uruguay Mobile', 227, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5995, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5997, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5999, 'Netherlands Antilles Curacao', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6115, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6116, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6128, 'Australia Sydney', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6129, 'Australia Sydney', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6138, 'Australia Melbourne', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6139, 'Australia Melbourne', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6140, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6141, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6142, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6143, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6144, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6145, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6146, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6147, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6148, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6149, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6186, 'Australia Perth', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6187, 'Australia Adelaide', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6188, 'Australia Adelaide', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6221, 'Indonesia Jakarta', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6231, 'Indonesia Surabaya', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6281, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6282, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6283, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6285, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6286, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6288, 'Indonesia Mobile', 100, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6420, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6421, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6422, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6423, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6424, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6425, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6426, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6427, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6428, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6429, 'New Zealand Mobile', 153, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6479, 'skeins anchorperson epitomizes', NULL, 'hashish''s physician''s lapel', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6534, 'neutrinos lowing rosebush', 63, 'attached fortify redeemer''s', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6670, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6672, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6675, 'unpremeditated jalape?os hubcap', 181, 'incompleteness''s loincloth''s accrual''s', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6681, 'Thaliand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6683, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6684, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6685, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6686, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6687, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6689, 'Thailand Mobile', 210, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6707, 'East Timor Mobile', 243, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6721, 'Antarctica', 8, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6723, 'Norfolk Island', 158, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6737, 'Brunei Darussalam Mobile', 32, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6738, 'Brunei Darussalam Mobile', 32, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6761, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6777, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6778, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6779, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6785, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6787, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6797, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6799, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6827, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6857, 'Samoa Mobile', 184, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6869, 'Kiribati Mobile', 111, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6877, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6878, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6879, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6886, 'Tuvalu Mobile', 220, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6892, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6897, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7096, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7097, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7301, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7302, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7342, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7343, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7345, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7349, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7352, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7381, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7382, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7383, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7385, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7388, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7394, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7411, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7413, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7415, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7416, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7423, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7424, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7426, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7427, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7495, 'Russia Moscow (Central)', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7499, 'Russia Moscow (Central)', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7700, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7701, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7702, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7705, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7707, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7760, 'Kazakhstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7761, 'Kazakhstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7762, 'Kazakhstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7763, 'Kazakhstan', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7764, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7771, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7775, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7777, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7812, 'Russia St Petersburg', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7814, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7815, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7818, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7821, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8152, 'Japan Nagoya', 107, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8166, 'Japan Osaka', 107, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8170, 'Japan Mobile', 107, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8180, 'Japan Mobile', 107, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8190, 'Japan Mobile', 107, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8201, 'South Korea Mobile', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8329, 'ebro''s episcopal illustrated', 232, 'rout''s grit hush', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8490, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8491, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8492, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8493, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8494, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8495, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8496, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8497, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8498, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8499, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8524, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8526, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8527, 'Hong Kong Pager', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8529, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8536, 'Macau Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8551, 'Cambodia Mobile', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8559, 'Cambodia Mobile', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8613, 'China Mobile', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8615, 'China Mobile', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8618, 'China Mobile', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8801, 'Bangladesh Mobile', 18, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8802, 'Bangladesh Dhaka', 18, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8816, 'Iridium', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8817, 'Iridium', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8860, 'exterior''s rubric friendly', NULL, 'evocation''s eggo binding', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8869, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(8957, 'c', 57, 'G', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9111, 'India Delhi', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9122, 'India Bombay', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9133, 'India Calcutta', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9140, 'India Hydrabad', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9180, 'India Bangalore', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9190, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9191, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9192, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9193, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9194, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9196, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9197, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9198, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9199, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9221, 'Pakistan Karachi', 162, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9242, 'Pakistan Lahore', 162, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9251, 'Pakistan Islamabad', 162, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9258, 'Pakistan Kashmir', 162, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9370, 'Afghanistan Mobile', 1, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9375, 'Afghanistan Mobile', 1, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9377, 'Afghanistan Mobile', 1, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9378, 'Afghanistan Mobile', 1, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9379, 'Afghanistan Mobile', 1, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9471, 'Sri Lanka Mobile', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9472, 'Sri Lanka Mobile', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9475, 'Sri Lanka Mobile', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9477, 'Sri Lanka Mobile', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9478, 'Sri Lanka Mobile', 199, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9607, 'Maldives Mobile', 130, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9608, 'Maldives Mobile', 130, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9609, 'Maldives Mobile', 130, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9613, 'Lebanon Mobile', 118, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9627, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9639, 'Syria Mobile', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9641, 'Iraq Baghdad', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9647, 'Iraq Mobile', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9651, 'Kuwait', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9652, 'Kuwait', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9656, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9657, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9659, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9661, 'Saudi Arabia Riyadh', 187, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9665, 'Saudi Arabia Mobile', 187, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9668, 'Saudi Arabia Mobile', 187, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9689, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9705, 'Palestine Mobile', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9714, 'United Arab Emirates Dubai', 223, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9725, 'Israel Mobile', 104, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9726, 'Israel Mobile', 104, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9733, 'Bahrain Mobile', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9742, 'Qatar Pager', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9743, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9745, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9746, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9747, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9751, 'Bhutan Mobile', 25, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9759, 'Bhutan Mobile', 25, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9769, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9771, 'Nepal Bhaktapur / Kathmandu', 149, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9821, 'Iran Tehran', 101, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9929, 'Tajikistan Mobile', 208, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9936, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9955, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9957, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9959, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9967, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9989, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(12843, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(14413, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(14417, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(17874, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18683, 'Trinidad & Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18684, 'Trinidad & Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18687, 'Trinidad & Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18695, 'St Kitts & Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18696, 'St Kitts & Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18697, 'St Kitts & Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18767, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21206, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21226, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21227, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21233, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21234, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21240, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21241, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21242, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21244, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21245, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21246, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21247, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21248, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21249, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21250, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21251, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21252, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21253, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21254, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21255, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21259, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21292, 'Morocco Mobile', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21355, 'Algeria [Wataniya]', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21366, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21369, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21377, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21379, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21396, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21398, 'Algeria Mobile', 3, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21620, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21621, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21622, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21623, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21624, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21625, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21626, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21640, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21679, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21690, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21691, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21692, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21693, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21694, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21695, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21696, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21697, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21698, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21699, 'Tunisia Mobile', 216, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21891, 'Libya Mobile', 121, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21892, 'Libya Mobile', 121, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(21894, 'Libya Mobile', 121, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22170, 'Senegal Mobile', 188, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22176, 'Senegal Mobile', 188, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22177, 'Senegal Mobile', 188, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22261, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22262, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22263, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22264, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22266, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22270, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22271, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22272, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22273, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22274, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22275, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22276, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22277, 'Mauritania Mobile', 135, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22330, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22331, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22332, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22333, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22334, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22340, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22341, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22344, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22345, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22346, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22347, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22350, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22351, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22352, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22353, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22354, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22355, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22356, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22357, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22358, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22359, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22360, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22361, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22362, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22363, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22364, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22365, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22366, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22367, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22368, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22369, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22385, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22386, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22387, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22388, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22389, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22390, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22391, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22392, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22393, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22394, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22395, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22396, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22397, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22398, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22399, 'Mali Mobile', 131, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22440, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22460, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22462, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22463, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22464, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22465, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22466, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22467, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22468, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22479, 'Guinea Mobile', 89, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22501, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22502, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22503, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22504, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22505, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22506, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22507, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22508, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22509, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22544, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22545, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22546, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22547, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22548, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22549, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22550, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22560, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22565, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22566, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22567, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22569, 'Ivory Coast Mobile', 53, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22670, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22671, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22672, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22675, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22676, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22678, 'Burkina Faso Mobile', 34, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22790, 'Niger Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22793, 'Niger Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22794, 'Niger Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22796, 'Niger Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22797, 'Niger Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22804, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22870, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22871, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22872, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22873, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22874, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22875, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22876, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22881, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22882, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22883, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22884, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22885, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22886, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22887, 'Togo Mobile', 212, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22990, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22991, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22992, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22993, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22994, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22995, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22996, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22997, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(22998, 'Benin Mobile', 23, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23021, 'Mauritius Pager', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23022, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23025, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23049, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23070, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23071, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23072, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23073, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23074, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23075, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23076, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23077, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23078, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23079, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23091, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23093, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23094, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23095, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23097, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23098, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23103, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23128, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23146, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23147, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23164, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23165, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23166, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23167, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23168, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23169, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23223, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23225, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23230, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23233, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23235, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23240, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23244, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23250, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23255, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23256, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23276, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23277, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23278, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23288, 'Sierra Leone Mobile', 190, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23320, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23321, 'Ghana Accra', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23323, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23324, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23326, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23327, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23328, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23354, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23470, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23480, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23490, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23530, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23531, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23532, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23533, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23534, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23535, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23562, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23567, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23598, 'Chad Mobile', 42, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23670, 'Central African Republic Mobil', 41, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23672, 'Central African Republic Mobil', 41, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23675, 'Central African Republic Mobil', 41, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23677, 'Central African Republic Mobil', 41, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23891, 'Cape Verde Mobile', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23895, 'Cape Verde Mobile', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23897, 'Cape Verde Mobile', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23898, 'Cape Verde Mobile', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23899, 'Cape Verde Mobile', 39, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23940, 'El Salvador', 64, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23990, 'Sao Tome and Principe Mobile', 186, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23998, 'Sao Tome & Principle Mobile', 186, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(23999, 'Sao Tome & Principle Mobile', 186, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24008, 'Equatorial Guinea Bata', 65, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24103, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24104, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24105, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24106, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24107, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24108, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24109, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24110, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24111, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24114, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24115, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24120, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24121, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24122, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24123, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24124, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24125, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24126, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24127, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24128, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24129, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24130, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24131, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24132, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24133, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24134, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24135, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24136, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24137, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24138, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24139, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24141, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24151, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24152, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24153, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24157, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24161, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24163, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24168, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24175, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24180, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24181, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24184, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24185, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24187, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24189, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24191, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24194, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24195, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24197, 'Gabon Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24294, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24295, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24296, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24297, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24298, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24299, 'Congo Mobile', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24322, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24378, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24380, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24381, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24384, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24385, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24388, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24389, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24397, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24398, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24399, 'Congo Democratic Republic Mobi', 49, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24491, 'Angola Mobile', 6, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24492, 'Angola Mobile', 6, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24493, 'Angola Mobile', 6, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24912, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24915, 'Sudan Canar', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24990, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24991, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24992, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24994, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24995, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(24999, 'Sudan Mobile', 200, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25003, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25005, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25006, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25008, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25072, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25075, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25078, 'Rwanda Mobile', 178, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25191, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25198, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25224, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25228, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25260, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25262, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25265, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25266, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25268, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25290, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25291, 'Somalia Mobile', 195, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25380, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25381, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25382, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25383, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25384, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25385, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25386, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25387, 'Djibouti Mobile', 59, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25420, 'Kenya Nairobi', 110, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25522, 'Tanzania Dar es Salaam', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25561, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25565, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25568, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25571, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25572, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25573, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25574, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25575, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25576, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25577, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25578, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25579, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25581, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25582, 'Tanzania Mobile', 209, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25639, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25671, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25675, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25677, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25678, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25729, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25776, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25777, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25778, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25779, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25882, 'Mozambique Mobile', 145, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(25884, 'Mozambique Mobile', 145, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26095, 'Zambia Mobile', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26096, 'Zambia Mobile', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26097, 'Zambia Mobile', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26098, 'Zambia Mobile', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26099, 'Zambia Mobile', 238, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26130, 'Madagascar Mobile', 127, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26132, 'Madagascar Mobile', 127, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26133, 'Madagascar Mobile', 127, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26134, 'Madagascar Mobile', 127, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269, 'Mayotte', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26311, 'Zimbabwe Mobile', 239, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26323, 'Zimbabwe Mobile', 239, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26391, 'Zimbabwe Mobile', 239, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26481, 'Namibia Mobile', 147, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26485, 'Namibia Mobile', 147, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26577, 'Malawi Mobile', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26588, 'Malawi Mobile(telekom)', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26599, 'Malawi Mobile(zain)', 128, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26771, 'Botswana Mobile', 28, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26772, 'Botswana Mobile', 28, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26773, 'Botswana Mobile', 28, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26774, 'Botswana Mobile', 28, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26860, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26861, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26862, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26863, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26864, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26865, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26866, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26867, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26877, 'Swaziland Mobile', 203, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27710, 'South Africa MTN Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27711, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27712, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27713, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27714, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27715, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27716, 'South Africa Vodacom Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27717, 'South Africa MTN Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27718, 'South Africa MTN Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(27719, 'South Africa MTN Mobile', 196, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29756, 'Aruba Mobile', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29759, 'Aruba Mobile', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29773, 'Aruba Mobile', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29774, 'Aruba Mobile', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29796, 'Aruba Mobile', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29799, 'Aruba Mobile', 12, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29821, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29822, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29823, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29824, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29825, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29826, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29827, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29828, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29829, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29871, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29872, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29873, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29874, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29875, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29876, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29877, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29879, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29891, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29892, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29893, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29894, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29895, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29896, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29897, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29898, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29899, 'Faeroes Islands Mobile', 70, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29942, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29943, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29944, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29945, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29946, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29947, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29948, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29949, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29950, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29952, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29953, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29954, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29955, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29956, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29957, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29958, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(29959, 'Greenland Mobile', 84, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(30231, 'Greece Thessaloniki', 83, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31611, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31614, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31615, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31616, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31617, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31618, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31619, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31621, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31624, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31625, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31626, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31627, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31628, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31629, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31631, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31633, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31634, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31638, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31639, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31641, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31642, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31643, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31644, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31645, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31646, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31647, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31648, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31649, 'Netherlands Mobile Telfort', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31650, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31652, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31654, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31655, 'Netherlands Mobile Vodafone', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31657, 'Netherlands Mobile KPN', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(31681, 'Netherlands Mobile T-Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32472, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32473, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32474, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32475, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32476, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32477, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32478, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32479, 'Belgium [Proximus]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32484, 'Belgium [Base]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32485, 'Belgium [Base]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32486, 'Belgium [Base]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32487, 'Belgium [Base]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32488, 'Belgium [Base]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32494, 'Belgium [Mobistar]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32495, 'Belgium [Mobistar]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32496, 'Belgium [Mobistar]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32497, 'Belgium [Mobistar]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32498, 'Belgium [Mobistar]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(32499, 'Belgium [Mobistar]', 21, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33262, 'Reunion', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33590, 'Guadeloupe', 86, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33594, 'French Guiana', 74, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33596, 'Martinique', 134, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33603, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33605, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33607, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33608, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33609, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33620, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33621, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33622, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33623, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33624, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33625, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33626, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33627, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33628, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33629, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33630, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33631, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33632, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33633, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33634, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33635, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33636, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33637, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33641, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33642, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33643, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33645, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33646, 'France SFR Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33647, 'France Orange Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33648, 'France Orange Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33650, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33653, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33654, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33655, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33658, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33659, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33660, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33661, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33662, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33663, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33664, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33665, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33666, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33667, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33668, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33669, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33670, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33671, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33672, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33673, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33674, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33675, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33676, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33677, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33678, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33679, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33680, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33681, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33682, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33683, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33684, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33685, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33686, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33687, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33688, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33689, 'France [Orange]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33698, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33699, 'France [Bouygues Telecom]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33777, 'France Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(33786, 'France Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34600, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34601, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34605, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34606, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34607, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34608, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34609, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34610, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34611, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34615, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34616, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34617, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34618, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34619, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34620, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34625, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34626, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34627, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34628, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34629, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34630, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34634, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34635, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34636, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34637, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34638, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34639, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34640, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34644, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34645, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34646, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34647, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34648, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34649, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34650, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34651, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34652, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34653, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34654, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34655, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34656, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34657, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34658, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34659, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34660, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34661, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34662, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34663, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34664, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34665, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34666, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34667, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34668, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34669, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34670, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34671, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34672, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34675, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34676, 'Spain Telefonica Moviles Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34677, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34678, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34679, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34680, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34684, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34685, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34686, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34687, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34688, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34689, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34690, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34691, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34692, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34693, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34695, 'Spain France Telecom Espana', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34696, 'Spain Telefonica Movile Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34697, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34698, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(34699, 'Spain Vodafone Mobile', 198, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35054, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35056, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35057, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35058, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35060, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35121, 'Portugal Lisbon', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35122, 'Portugal Oporto', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35221, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35228, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35260, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35261, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35268, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35291, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35298, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35383, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35385, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35386, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35387, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35388, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35389, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35438, 'Iceland Mobile Other', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35462, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35466, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35467, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35468, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35469, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35475, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35482, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35483, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35484, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35485, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35486, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35487, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35488, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35489, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35567, 'Albania Mobile', 2, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35568, 'Albania Mobile', 2, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35569, 'Albania Mobile', 2, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35672, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35677, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35679, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35692, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35694, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35699, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35796, 'Cyprus Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35797, 'Cyprus Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35799, 'Cyprus Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35850, 'Finland Mobile', 72, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35917, 'Bulgaria Pager', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35948, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35987, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35988, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35989, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35998, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35999, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37022, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37079, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37098, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37099, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37120, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37121, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37122, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37123, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37124, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37125, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37126, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37127, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37128, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37129, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37191, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37192, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37193, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37194, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37195, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37196, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37197, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37198, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37199, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37250, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37251, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37255, 'Estonia Tele2 Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37256, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37258, 'Estonia Tele2 Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37281, 'Estonia Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37282, 'Estonia Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37283, 'Estonia Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37284, 'Estonia Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37285, 'Estonia Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37322, 'Moldova Chisinau', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37368, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37369, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37379, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37410, 'Armenia Yerevan', 11, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37455, 'Armenia Mobile', 11, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37477, 'Armenia Mobile', 11, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37517, 'Belarus Minsk', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37525, 'Belarus Mobile', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37529, 'Belarus Mobile', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37533, 'Belarus Mobile', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37544, 'Belarus Mobile', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37744, 'Monaco - Kosovo Mobile', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37745, 'Monaco - Kosovo Mobile', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37746, 'Monaco - Africa Mobile', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37747, 'Monaco - Africa Mobile', 141, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38032, 'Ukraine Lviv', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38039, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38044, 'Ukraine Kiev', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38045, 'Ukraine Kiev', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38048, 'Ukraine Odessa', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38050, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38056, 'Ukraine Dnipropetrovsk', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38057, 'Ukraine Kharkiv', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38062, 'Ukraine Donetsk', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38063, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38066, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38067, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38068, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38091, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38092, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38093, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38094, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38095, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38096, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38097, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38098, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38099, 'Ukraine Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38263, 'Montenegro Mobile', 252, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38267, 'Montenegro Mobile', 252, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38268, 'Montenegro Mobile', 252, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38269, 'Montenegro Mobile', 252, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38509, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38591, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38592, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38595, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38597, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38598, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38599, 'Croatia Mobile', 54, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38630, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38631, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38640, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38641, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38643, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38649, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38650, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38651, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38664, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38665, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38666, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38667, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38668, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38669, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38670, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38671, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38698, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38951, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38970, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38971, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38972, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38973, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38974, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38975, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38976, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38977, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38978, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(38979, 'Macedonia Mobile', 126, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39370, 'Italy Mobile TIM', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39373, 'Italy Mobile H3G', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39377, 'Italy Mobile Vodafone', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39380, 'Italy Mobile Wind', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39383, 'Italy Mobile Vodafone', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39385, 'Italy Mobile TIM', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39388, 'Italy Mobile Wind', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(39389, 'Italy Mobile Wind', 105, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41762, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41763, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41764, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41765, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41786, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41787, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41788, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41792, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41793, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41794, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41795, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41796, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(41797, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42060, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42072, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42073, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42077, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42079, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42093, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42096, 'Czech Republic Mobile', 57, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42190, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42191, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(42194, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43644, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43650, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43651, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43652, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43653, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43655, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43657, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43659, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43660, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43661, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43662, 'Austria Salzburg', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43663, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43664, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43665, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43666, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43667, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43668, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43669, 'Austria Other Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43676, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43677, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43678, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43680, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43681, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43688, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(43699, 'Austria Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44113, 'Leeds', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44114, 'Sheffield', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44115, 'Nottingham', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44116, 'Leicester', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44117, 'Bristol', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44118, 'Reading', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44121, 'Birmingham', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44131, 'Edinburgh', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44141, 'Glasgow', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44151, 'Liverpool', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44161, 'Manchester', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44191, 'Tyneside  Durham & Wearside', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44500, 'UK Free', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44800, 'UK Free', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44808, 'UK Free', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44844, 'UK Special', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44845, 'UK Non-geo Local', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870, 'UK Non-geo National', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45411, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45412, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45413, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45414, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45415, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45416, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45417, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45418, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45419, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45420, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45421, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45422, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45423, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45424, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45425, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45532, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45534, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45535, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45536, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45537, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45538, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45539, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45713, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45714, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45715, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45716, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(45718, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46252, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46376, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46518, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46519, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46655, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46656, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46673, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46674, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46675, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46676, 'Sweden Mobile', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46702, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46703, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46705, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46706, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46708, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46709, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(46733, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(47800, 'Norway [FREE]', 160, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48530, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48531, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48533, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48535, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48600, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48601, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48602, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48603, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48604, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48605, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48606, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48607, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48608, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48609, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48642, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48660, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48661, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48662, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48663, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48664, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48665, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48666, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48667, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48668, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48669, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48690, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48691, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48692, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48693, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48694, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48695, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48696, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48697, 'Poland Mobile Plus', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48698, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48699, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48720, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48721, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48722, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48723, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48724, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48725, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48726, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48729, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48780, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48781, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48782, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48783, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48784, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48785, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48786, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48787, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48788, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48789, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48790, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48791, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48792, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48793, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48794, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48795, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48796, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48797, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48798, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48799, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48880, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48881, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48882, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48883, 'Poland Mobile Era', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48884, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48885, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48886, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48887, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48888, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(48889, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49150, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49151, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49152, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49155, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49156, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49157, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49159, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49160, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49162, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49163, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49170, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49171, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49172, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49173, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49174, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49175, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49176, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49177, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49178, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(49179, 'Germany Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50487, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50488, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50489, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50855, 'St Pierre and Miquelon Mobile', 182, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50922, 'Haiti Port au Prince', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50981, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50982, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50983, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50990, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50991, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50992, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50993, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(50994, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51418, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51419, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51428, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51429, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51438, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51439, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51448, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51449, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51518, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51519, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51528, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51529, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51538, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51539, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51548, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51549, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51568, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51569, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51618, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51619, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51628, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51629, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51638, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51639, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51648, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51649, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51658, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51659, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51668, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51669, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51678, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51679, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51728, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51729, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51738, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51739, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51748, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51749, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51768, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51769, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51828, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51829, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51839, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51848, 'Peru Rural', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(51849, 'Peru Mobile', 168, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55116, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55117, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55118, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55119, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55126, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55127, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55128, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55129, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55136, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55137, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55138, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55139, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55146, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55147, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55148, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55149, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55156, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55157, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55158, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55159, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55166, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55167, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55168, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55169, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55176, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55177, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55178, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55179, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55186, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55187, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55188, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55189, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55196, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55197, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55198, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55199, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55209, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55217, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55218, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55219, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55226, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55227, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55228, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55229, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55236, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55237, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55238, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55239, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55246, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55247, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55248, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55249, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55256, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55257, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55258, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55259, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55267, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55268, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55269, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55277, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55278, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55279, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55286, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55287, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55288, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55289, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55297, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55298, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55299, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55309, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55316, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55317, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55318, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55319, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55326, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55327, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55328, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55329, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55336, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55337, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55338, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55339, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55346, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55347, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55348, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55349, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55356, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55357, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55358, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55359, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55367, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55368, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55369, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55376, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55377, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55379, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55386, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55387, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55388, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55389, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55397, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55398, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55399, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55409, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55416, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55417, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55418, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55419, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55426, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55427, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55428, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55429, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55436, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55437, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55438, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55439, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55446, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55447, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55448, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55449, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55457, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55458, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55459, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55467, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55468, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55469, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55477, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55479, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55486, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55487, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55488, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55489, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55497, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55498, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55499, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55509, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55516, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55517, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55518, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55519, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55527, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55528, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55529, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55536, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55537, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55538, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55539, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55546, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55547, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55548, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55549, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55556, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55557, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55558, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55559, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55567, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55568, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55569, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55577, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55579, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55587, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55588, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55589, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55597, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55598, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55599, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55609, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55616, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55617, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55618, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55619, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55626, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55627, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55628, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55629, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55636, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55637, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55638, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55639, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55646, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55647, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55648, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55649, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55656, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55657, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55658, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55659, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55666, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55667, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55668, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55669, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55676, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55677, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55678, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55679, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55686, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55687, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55688, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55689, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55696, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55697, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55698, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55699, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55709, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55716, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55717, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55718, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55719, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55727, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55728, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55729, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55737, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55738, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55739, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55747, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55748, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55749, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55757, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55758, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55759, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55767, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55768, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55769, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55777, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55778, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55779, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55787, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55789, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55797, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55798, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55799, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55809, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55817, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55818, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55819, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55827, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55828, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55829, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55837, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55838, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55839, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55846, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55847, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55848, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55849, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55856, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55857, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55858, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55859, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55867, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55868, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55869, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55877, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55878, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55879, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55887, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55888, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55889, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55897, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55898, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55899, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55909, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55917, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55918, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55919, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55927, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55928, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55929, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55937, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55938, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55939, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55947, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55948, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55949, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55957, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55958, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55959, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55967, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55968, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55969, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55977, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55978, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55979, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55987, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55988, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55989, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55997, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55998, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(55999, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57300, 'Colombia [Ola]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57301, 'Colombia [Ola]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57304, 'Colombia [Ola]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57310, 'Colombia [Comcel]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57311, 'Colombia [Comcel]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57312, 'Colombia [Comcel]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57313, 'Colombia [Comcel]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57314, 'Colombia [Comcel]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57315, 'Colombia [Movistar]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57316, 'Colombia [Movistar]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57317, 'Colombia [Movistar]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57318, 'Colombia [Movistar]', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57532, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57533, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57534, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57535, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57536, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57537, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(57543, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(58212, 'Venezuela Caracas', 230, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59262, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59264, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59266, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59267, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59268, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59269, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59521, 'Paraguay Asuncion', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59597, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59598, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59599, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59771, 'Suriname Mobile', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59772, 'Suriname Mobile', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59775, 'Suriname Mobile', 201, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59951, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59952, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59954, 'Netherlands Antilles St Maarten', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59955, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59956, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59958, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59970, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59978, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59979, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59980, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59995, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(59996, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61140, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61144, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61145, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61146, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61147, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61148, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61149, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61170, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61171, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61172, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61174, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61177, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61178, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61179, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61181, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61182, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61183, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61184, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61185, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61186, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61187, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61188, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61189, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61191, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61193, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61194, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61196, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61199, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61261, 'Australia Canberra', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61262, 'Australia Canberra', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61892, 'Australia Perth', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61893, 'Australia Perth', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(61894, 'Australia Perth', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67071, 'East Timor Mobile', 243, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67072, 'East Timor Mobile', 243, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67073, 'East Timor Mobile', 243, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67079, 'East Timor Mobile', 243, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67210, 'Antarctica', 8, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67211, 'Antarctica', 8, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67212, 'Antarctica', 8, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67213, 'Antarctica', 8, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67235, 'Norfolk Island Mobile', 158, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67238, 'Norfolk Island Mobile', 158, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67455, 'Nauru Mobile', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67563, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67565, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67567, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67568, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67569, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67571, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67572, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67576, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67611, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67612, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67613, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67614, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67615, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67616, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67617, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67618, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67619, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67645, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67646, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67647, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67648, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67649, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67652, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67653, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67654, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67655, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67656, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67657, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67658, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67659, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67662, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67663, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67664, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67665, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67666, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67667, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67668, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67669, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67675, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67676, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67677, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67678, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67681, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67682, 'Tonga Mobile', 214, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67742, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67743, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67744, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67745, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67746, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67747, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67749, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67754, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67755, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67756, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67757, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67758, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67759, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67765, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67766, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67768, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67769, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67774, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67853, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67854, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67855, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67856, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67877, 'Vanuatu Mobile', 229, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67970, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67971, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67972, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67973, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67974, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67983, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67984, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67986, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(67987, 'Fiji Mobile', 71, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68250, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68251, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68252, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68253, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68254, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68255, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68256, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68258, 'Cook Islands Mobile', 51, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68630, 'Kiribati Mobile', 111, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68650, 'Kiribati Mobile', 111, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68689, 'Kiribati Mobile', 111, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68774, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68775, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68776, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68777, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68778, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68779, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68780, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68781, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68782, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68783, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68784, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68785, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68786, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68787, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68789, 'New Caledonia Mobile', 152, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68890, 'Tuvalu Mobile', 220, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68930, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68931, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68932, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68933, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(68939, 'French Polynesia Mobile', 75, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(70822, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73020, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73021, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73023, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73024, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73025, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73026, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73027, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73028, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73029, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73430, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73431, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73434, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73436, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73437, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73438, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73439, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73450, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73451, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73453, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73454, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73455, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73456, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73457, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73458, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73459, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73494, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73820, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73821, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73824, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73825, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73826, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73827, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73828, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73829, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73842, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73850, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73851, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73853, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73855, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73856, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73857, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73858, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73859, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73880, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73881, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73883, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73884, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73885, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73886, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73887, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73888, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73889, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73940, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73941, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73943, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73944, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73945, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73946, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73947, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73948, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73949, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(74112, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(74217, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77129, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77139, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77149, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77159, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77179, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77189, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77219, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77239, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77249, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77259, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77269, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77275, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(77279, 'Kazakstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84121, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84122, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84123, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84125, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84126, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84127, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84128, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84129, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84164, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84165, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84166, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84167, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84168, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84169, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(84199, 'Viet Nam Mobile', 231, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85217, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85251, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85253, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85254, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85256, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85259, 'Hong Kong Mobile', 96, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85360, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85361, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85362, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85363, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85365, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85366, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85368, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85369, 'Macao Mobile', 125, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85581, 'Cambodia Mobile', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85585, 'Cambodia Mobile', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85589, 'Cambodia Mobile', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85595, 'Cambodia Pager', 36, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(85620, 'Laos Mobile', 116, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(86147, 'China Mobile', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(86180, 'China Mobile', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(86189, 'China Mobile', 44, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88030, 'Bangladesh Chittagong', 18, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88031, 'Bangladesh Chittagong', 18, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88213, 'Emsat (Satellite)', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88216, 'Thuraya', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88660, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88670, 'Taiwan Pager', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88690, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88691, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88692, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88693, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88694, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88695, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88696, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88697, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(88698, 'Taiwan Mobile', 207, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(90212, 'Turkey Istanbul (Europe)', 217, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(90213, 'Turkey Istanbul (Europe)', 217, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(90216, 'Turkey Istanbul (Asia)', 217, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(90217, 'Turkey Istanbul (Asia)', 217, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(90392, 'Cyprus (North)', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96170, 'Lebanon Mobile', 118, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96171, 'Lebanon Mobile', 118, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96274, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96277, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96278, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96279, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96392, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96393, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96394, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96395, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96396, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96398, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96399, 'Syrian Arab Republic Mobile', 206, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96540, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96544, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96550, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96551, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96555, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96558, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96559, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96571, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96572, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96573, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96574, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96575, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96576, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96578, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96579, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96758, 'Yemen Mobile', 236, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96771, 'Yemen Mobile', 236, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96773, 'Yemen Mobile', 236, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96777, 'Yemen Mobile', 236, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96872, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96891, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96892, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96895, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96896, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96897, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96898, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(96899, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97059, 'Palestinian Territory Mobile', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97150, 'United Arab Emirates Mobile', 223, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97155, 'United Arab Emirates Mobile', 223, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97156, 'United Arab Emirates Mobile', 223, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97222, 'Palestinian Territory', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97232, 'Palestinian Territory', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97242, 'Palestinian Territory', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97259, 'Palestinian Territory Mobile', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97282, 'Palestinian Territory', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97292, 'Palestinian Territory', 164, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97420, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97421, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97422, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97430, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97431, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97432, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97433, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97434, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97435, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97436, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97460, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97461, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97462, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97464, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97465, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97466, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97467, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97468, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97469, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97517, 'Bhutan Mobile', 25, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97688, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97691, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97693, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97695, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97696, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97698, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97699, 'Mongolia Mobile', 142, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(97798, 'Nepal Mobile', 149, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99412, 'Azerbaijan Baku', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99440, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99450, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99451, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99455, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99460, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99470, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99477, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99532, 'Georgia Tbilisi', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99550, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99551, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99554, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99555, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99557, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99558, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99562, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99571, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99572, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99574, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99577, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99579, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99590, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99591, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99593, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99595, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99596, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99597, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99598, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99599, 'Georgia Mobile', 79, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99651, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99654, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99655, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99656, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99657, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99658, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99670, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99677, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99871, 'Uzbekistan [Tashkent]', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99890, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99891, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99892, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99893, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99894, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99895, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99897, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99898, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99899, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118111, '118111', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118118, 'The Number UK Limited', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118119, '192.com', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118147, 'thephonebook.co.uk', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118180, 'Telewest', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118247, 'Yellow Pages', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118321, 'Tesco Directory', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118500, 'BT', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118505, 'BT (Intl)', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118511, 'British Gas', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118800, 'Kingston Communications', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118878, 'ntl', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(118888, '118 UK', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124235, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124242, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124245, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124247, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124255, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124623, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124624, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124625, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124626, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124645, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124652, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(124682, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(144150, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(144151, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(144152, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(144153, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(144159, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(147341, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(164923, 'Turks & Caicos Islands Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(164924, 'Turks & Caicos Islands Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(164933, 'Turks & Caicos Islands Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(164934, 'Turks & Caicos Islands Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(164943, 'Turks & Caicos Islands Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(164944, 'Turks & Caicos Islands Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(167168, 'Guam Mobile', 87, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(167172, 'Guam Mobile', 87, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(175871, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(175872, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178720, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178721, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178723, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178724, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178730, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178731, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178732, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178733, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178734, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178735, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178736, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178737, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178738, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178739, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178740, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178742, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178751, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178752, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178753, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178754, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178757, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178758, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178759, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178760, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178761, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178763, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178764, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(178796, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180920, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180921, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180922, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180923, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180930, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180935, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180939, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180940, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180942, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180944, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180949, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180950, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180951, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180964, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180965, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180966, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180967, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180970, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180971, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180978, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180984, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180986, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180988, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180990, 'Domincan Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180991, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180995, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180996, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180997, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180998, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180999, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182920, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182921, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182923, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182924, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182925, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182926, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182927, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182928, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182929, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182931, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182932, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182933, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182934, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182935, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182936, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182937, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182938, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182939, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182940, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182941, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182942, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182943, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182944, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182945, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182946, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182947, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182948, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182949, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182950, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182951, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182952, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182953, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182954, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182955, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182960, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182961, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182962, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182963, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182964, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182965, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182966, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182967, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182968, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182969, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182970, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182971, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182972, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182974, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182975, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182976, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182977, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182978, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182979, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182980, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182981, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182982, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182983, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182985, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182986, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182987, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182988, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182990, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182991, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182992, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182993, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182997, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(182998, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186829, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186832, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186833, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186834, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186835, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186836, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186837, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186838, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186839, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186846, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186847, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186848, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186849, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186868, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186872, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186873, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186874, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186875, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186876, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186877, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186878, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(186879, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187628, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187629, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187630, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187631, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187632, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187633, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187634, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187635, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187636, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187637, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187638, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187639, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187640, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187642, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187643, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187644, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187645, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187646, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187647, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187648, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187649, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187650, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187652, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187653, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187654, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187656, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187657, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187658, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187659, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187677, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187681, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187682, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187683, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187684, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187685, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187686, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187687, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187688, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(187689, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212520, 'Morocco Casablanca', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212521, 'Morocco Casablanca', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212522, 'Morocco Casablanca', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212526, 'Morocco Wana', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212527, 'Morocco Wana', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212529, 'Morocco Wana', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212533, 'Morocco Wana', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212534, 'Morocco Wana', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(212538, 'Morocco Wana', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230219, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230421, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230422, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230423, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230428, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230429, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230871, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230875, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230876, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(230877, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(231880, 'Liberia Mobile', 120, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234700, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234702, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234703, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234704, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234705, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234706, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234707, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234708, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234709, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234812, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234813, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(234819, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(241144, 'Gabon Libreville', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251920, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251921, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251922, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251923, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251958, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(251959, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(256700, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(256701, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(256702, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(256703, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(256704, 'Uganda Mobile', 221, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(262269, 'Mayotte', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(262639, 'Mayotte Mobile', 137, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(262692, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(262693, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(266212, 'Lesotho Mobile', 119, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(291171, 'Eritrea Mobile', 66, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(291172, 'Eritrea Mobile', 66, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(291173, 'Eritrea Mobile', 66, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(316305, 'Netherlands Mobile KPN', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(316831, 'Netherlands Mobile KPN', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(316832, 'Netherlands Mobile KPN', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(316833, 'Netherlands Mobile KPN', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(316834, 'Netherlands Mobile KPN', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336001, 'France Orange Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336002, 'France SFR Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336003, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336005, 'France SFR Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336007, 'France SFR Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336008, 'France Orange Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336009, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336530, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336531, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336532, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336533, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(336534, 'France Bouygues Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(351291, 'Portugal Madeira Island', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(351292, 'Portugal Azores', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(351295, 'Portugal Azores', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(351296, 'Portugal Azores', 172, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352021, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352028, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352061, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352068, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352091, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352098, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352621, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352628, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352661, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352668, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352691, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(352698, 'Luxembourg Mobile', 124, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(353821, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(353822, 'Ireland Mobile', 103, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354373, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354374, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354380, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354385, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354388, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354389, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354610, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354614, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354615, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354616, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354617, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354618, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354630, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354631, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354632, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354637, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354638, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354639, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354640, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354641, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354642, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354649, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354650, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354652, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354655, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354659, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354770, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354771, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354772, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354773, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354774, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354775, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354776, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354777, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354954, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(354958, 'Iceland Mobile', 98, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(356777, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(357976, 'Cyprus Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(357977, 'Cyprus Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(359430, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(359437, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(359438, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(359439, 'Bulgaria Mobile', 33, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(370393, 'Lithuania Mobile', 123, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372530, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372534, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372537, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372538, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372539, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372572, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372573, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372574, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372575, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372576, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372577, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372578, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372579, 'Estonia Elisa Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372590, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(372591, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373600, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373601, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373602, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373650, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373671, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373672, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373673, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373680, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373681, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373682, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373683, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373684, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373685, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373686, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373687, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373688, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373774, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373777, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373778, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373779, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373780, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373781, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373782, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373783, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(373788, 'Moldova Mobile', 140, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(375256, 'Belarus Mobile', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(375259, 'Belarus Mobile', 20, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386641, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386642, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386643, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386644, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386645, 'Slovenia Mobile', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(386817, 'Slovenia Mobitel Pats', 193, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417670, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417671, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417672, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417673, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417674, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417740, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417741, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417742, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417743, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417744, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417745, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417746, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417747, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417830, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417831, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417832, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417890, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417891, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417892, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417893, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417894, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417895, 'Switzerland Orange Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417980, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417981, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417982, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417983, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417984, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417985, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417986, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417987, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(417988, 'Switzerland Swisscom Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421901, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421902, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421903, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421904, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421905, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421906, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421907, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421908, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421909, 'Slovakia Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421910, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421911, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421912, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421913, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421914, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421915, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421916, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421917, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421918, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421919, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421940, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421944, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421948, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(421949, 'Slovak Republic Mobile', 192, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436772, 'Austria T-Mobile Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436778, 'Austria T-Mobile Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436801, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436802, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436803, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436804, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436805, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436806, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436807, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(436998, 'Austria Mobilkom Mobile', 14, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441200, 'Clitheroe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441202, 'Bournemouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441204, 'Bolton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441205, 'Boston', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441206, 'Colchester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441207, 'Consett', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441208, 'Bodmin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441209, 'Redruth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441223, 'Cambridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441224, 'Aberdeen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441225, 'Bath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441226, 'Barnsley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441227, 'Canterbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441228, 'Carlisle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441229, 'Barrow-in-Furness & Millom', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441233, 'Ashford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441234, 'Bedford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441235, 'Abingdon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441236, 'Coatbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441237, 'Bideford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441239, 'Cardigan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441241, 'Arbroath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441242, 'Cheltenham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441243, 'Chichester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441244, 'Chester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441245, 'Chelmsford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441246, 'Chesterfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441248, 'Bangor (N Wales)', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441249, 'Chippenham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441250, 'Blairgowrie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441252, 'Aldershot', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441253, 'Blackpool', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441254, 'Blackburn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441255, 'Clacton-on-Sea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441256, 'Basingstoke', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441257, 'Coppull', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441258, 'Blandford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441259, 'Alloa', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441260, 'Congleton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441261, 'Banff', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441262, 'Bridlington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441263, 'Cromer', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441264, 'Andover', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441267, 'Carmarthen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441268, 'Stanford-le-Hope', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441269, 'Ammanford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441270, 'Crewe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441271, 'Barnstable', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441273, 'Brighton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441274, 'Bradford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441275, 'Bristol', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441276, 'Ascot', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441277, 'Brentwood', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441278, 'Bridgwater', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441279, 'Bishops Stortford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441280, 'Buckingham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441282, 'Burnley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441283, 'Burton-on-Trent', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441284, 'Bury-St-Edmunds', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441285, 'Cirencester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441286, 'Caernarvon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441287, 'Guisborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441288, 'Bude', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441289, 'Berwick-on-Tweed', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441290, 'Cumnock', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441291, 'Shirenewton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441292, 'Ayr', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441293, 'Newdigate', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441294, 'Ardrossan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441295, 'Banbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441296, 'Aylesbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441297, 'Axminster', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441298, 'Buxton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441299, 'Bewdley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441300, 'Cerne Abbas', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441301, 'Arrochar', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441302, 'Doncaster', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441303, 'Folkestone', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441304, 'Dover', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441305, 'Dorchester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441306, 'Newdigate', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441307, 'Forfar', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441308, 'Bridport', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441309, 'Forres', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441320, 'Fort Augustus', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441322, 'Swanley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441323, 'Eastbourne', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441324, 'Falkirk', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441325, 'Darlington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441326, 'Falmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441327, 'Weedon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441328, 'Fakenham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441329, 'Fareham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441330, 'Banchory', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441332, 'Derby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441333, 'Peat Inn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441334, 'Peat Inn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441335, 'Ashbourne', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441337, 'Ladybank', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441339, 'Aboyne & Ballater', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441340, 'Craigellachie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441341, 'Barmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441342, 'East Grinstead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441343, 'Elgin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441344, 'Ascot', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441346, 'Fraserburgh', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441347, 'Easingwold', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441348, 'Fishguard', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441349, 'Dingwall', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441350, 'Dunkeld', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441352, 'Mold', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441353, 'Ely', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441354, 'Doddington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441355, 'East Kilbride', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441356, 'Brechin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441357, 'East Kilbride', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441358, 'Ellon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441359, 'Pakenham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441360, 'Killearn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441361, 'Duns', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441362, 'Dereham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441363, 'Crediton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441364, 'Ashburton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441366, 'Downham Market', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441367, 'Faringdon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441368, 'Dunbar', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441369, 'Dunoon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441371, 'Great Dunmow', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441372, 'Esher', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441373, 'Frome', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441375, 'Stanford-le-Hope', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441376, 'Braintree', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441377, 'Driffield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441379, 'Diss', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441380, 'Devizes', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441381, 'Fortrose', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441382, 'Dundee', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441383, 'Dunfermline', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441384, 'Stourbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441386, 'Evesham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441387, 'Dumfries & Langholm', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441388, 'Bishop Auckland & Stanhope', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441389, 'Dumbarton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441392, 'Exeter', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441394, 'Shottisham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441395, 'Budleigh Salterton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441397, 'Fort William', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441398, 'Dulverton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441400, 'Honington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441403, 'Horsham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441404, 'Honiton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441405, 'Goole', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441406, 'Holbeach', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441407, 'Holyhead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441408, 'Golspie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441409, 'Holsworthy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441411, 'Glasgow National dialling', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441420, 'Alton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441422, 'Halifax', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441423, 'Harrogate & Boroughbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441424, 'Hastings', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441425, 'Burley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441427, 'Gainsborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441428, 'Haslemere', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441429, 'Hartlepool', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441430, 'North Cave & Market Weighton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441431, 'Helmsdale', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441432, 'Hereford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441433, 'Hathersage', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441434, 'Bellingham  Haltwhistle & Hexha', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441435, 'Heathfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441436, 'Helensburgh', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441437, 'Haverfordwest & Clynderwen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441438, 'Knebworth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441439, 'Helmsley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441440, 'Haverhill', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441442, 'Markyate', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441443, 'Pontypridd', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441444, 'Haywards Heath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441445, 'Gairloch', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441446, 'Barry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441449, 'Stowmarket', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441450, 'Hawick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441451, 'Bourton-on-the-Water', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441452, 'Gloucester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441453, 'Dursley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441454, 'Rangeworthy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441455, 'Hinckley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441456, 'Glenurquhart', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441457, 'Glossop', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441458, 'Glastonbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441460, 'Chard', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441461, 'Annan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441462, 'Hitchin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441463, 'Inverness', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441464, 'Insch', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441465, 'Girvan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441466, 'Huntly', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441467, 'Inverurie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441469, 'Killingholme', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441470, 'Edinbane', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441471, 'Broadford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441472, 'Grimsby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441473, 'Ipswich', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441474, 'Gravesend', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441475, 'Greenock', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441476, 'Grantham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441477, 'Congleton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441478, 'Portree', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441479, 'Grantown-on-Spey', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441480, 'Huntingdon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441481, 'Guernsey', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441482, 'Hull', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441483, 'Guildford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441484, 'Huddersfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441485, 'Docking', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441487, 'Warboys', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441488, 'Great Shefford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441489, 'Fareham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441490, 'Corwen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441491, 'Nettlebed', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441492, 'Colwyn Bay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441493, 'Great Yarmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441494, 'High Wycombe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441495, 'Pontypool', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441496, 'Port Ellen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441497, 'Hay-on-Wye', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441499, 'Inveraray', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441501, 'Harthill', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441502, 'Lowestoft', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441503, 'Looe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441505, 'Johnstone', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441506, 'Bathgate', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441507, 'Louth  Alford (Lincs) & Spilsby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441508, 'Brooke', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441509, 'Loughborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441520, 'Lochcarron', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441522, 'Lincoln', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441524, 'Lancaster & Hornby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441525, 'Leighton Buzzard', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441526, 'Martin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441527, 'Redditch', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441528, 'Laggan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441529, 'Sleaford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441530, 'Coalville', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441531, 'Ledbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441534, 'Jersey', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441535, 'Keighley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441536, 'Kettering', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441538, 'Ipstones/Leek', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441539, 'Kendal  Grange over Sands  Sedb', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441540, 'Kingussie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441542, 'Keith', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441543, 'Burntwood', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441544, 'Kington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441545, 'Llanarth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441546, 'Lochgilphead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441547, 'Knighton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441548, 'Kingsbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441549, 'Lairg', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441550, 'Llandovery', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441553, 'Kings Lynn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441554, 'Llanelli', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441555, 'Lanark', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441556, 'Castle Douglas', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441557, 'Kirkcudbright', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441558, 'Llandeilo', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441559, 'Llandyssul', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441560, 'Moscow', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441561, 'Fordoun', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441562, 'Stourbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441563, 'Kilmarnock', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441564, 'Lapworth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441565, 'Knutsford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441566, 'Launceston', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441567, 'Killin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441568, 'Leominster', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441569, 'Stonehaven', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441570, 'Lampeter', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441571, 'Lochinver', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441572, 'Oakham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441573, 'Kelso', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441575, 'Kirriemuir', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441576, 'Lockerbie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441577, 'Kinross', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441578, 'Lauder', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441579, 'Liskeard', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441580, 'Cranbrook', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441581, 'New Luce', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441582, 'Markyate', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441583, 'Carradale', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441584, 'Ludlow', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441586, 'Campbeltown', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441588, 'Craven Arms', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441590, 'Lymington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441591, 'Llanwrtyd Wells', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441592, 'Kirkcaldy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441593, 'Lybster', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441594, 'Lydney', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441595, 'Lerwick Foula & Fair Isle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441597, 'Llandrindod Wells', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441598, 'Brayford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441599, 'Kyle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441600, 'Monmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441603, 'Norwich', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441604, 'Northampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441606, 'Northwich', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441608, 'Chipping Norton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441609, 'Northallerton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441611, 'Manchester National dialling', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441620, 'North Berwick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441621, 'Maldon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441622, 'Maidstone', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441623, 'Mansfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441624, 'Isle of Man', 249, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441625, 'Macclesfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441626, 'Newton Abbot', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441628, 'Maidenhead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441629, 'Matlock', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441630, 'Market Drayton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441631, 'Oban', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441633, 'Newport', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441634, 'Medway', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441635, 'Newbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441636, 'Newark', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441637, 'Newquay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441638, 'Newmarket', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441639, 'Neath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441641, 'Strathy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441642, 'Middlesbrough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441643, 'Minehead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441644, 'New Galloway', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441646, 'Milford Haven', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441647, 'Moretonhampstead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441650, 'Cemmaes Road', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441651, 'Oldmeldrum', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441652, 'Brigg', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441653, 'Malton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441654, 'Machynlleth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441655, 'Maybole', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441656, 'Bridgend', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441659, 'Sanquhar', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441661, 'Wylam', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441663, 'New Mills', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441664, 'Melton Mowbray', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441665, 'Alnwick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441666, 'Malmesbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441667, 'Nairn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441668, 'Belford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441669, 'Rothbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441670, 'Morpeth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441671, 'Newton Stewart', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441672, 'Marlborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441673, 'Market Rasen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441674, 'Montrose', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441675, 'Meriden', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441676, 'Meriden', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441677, 'Bedale', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441678, 'Bala', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441680, 'Craignure', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441681, 'Fionnphort', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441683, 'Moffat', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441684, 'Hanley Swan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441685, 'Merthyr Tydfil', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441686, 'Newtown & Llanidloes', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441687, 'Mallaig', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441688, 'Tobermory', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441689, 'Swanley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441690, 'Betws-y-Coed', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441691, 'Oswestry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441692, 'North Walsham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441694, 'Church Stretton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441695, 'Skelmersdale (Rainford)', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441697, 'Brampton  Wigton & Raughton Hea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441698, 'Motherwell', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441700, 'Rothesay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441702, 'Southend-on-Sea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441704, 'Southport', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441706, 'Rochdale', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441707, 'Colney Heath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441708, 'Romford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441709, 'Rotherham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441720, 'Scillonia', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441721, 'Peebles', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441722, 'Salisbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441723, 'Scarborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441724, 'Scunthorpe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441725, 'Rockbourne', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441726, 'St Austell', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441727, 'Colney Heath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441728, 'Saxmundham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441729, 'Settle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441730, 'Petersfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441732, 'Sevenoaks', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441733, 'Peterborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441736, 'Penzance', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441737, 'Merstham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441738, 'Perth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441740, 'Sedgefield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441743, 'Shrewsbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441744, 'Rainford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441745, 'Rhyl', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441746, 'Bridgnorth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441747, 'Shaftesbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441748, 'Richmond', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441749, 'Shepton Mallet', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441750, 'Selkirk', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441751, 'Pickering', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441752, 'Plymouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441753, 'Iver', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441754, 'Skegness', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441756, 'Skipton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441757, 'Selby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441758, 'Pwllheli', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441759, 'Pocklington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441760, 'Swaffham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441761, 'Temple Cloud', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441763, 'Royston', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441764, 'Crieff', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441765, 'Ripon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441766, 'Porthmadog', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441767, 'Sandy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441768, 'Penrith  Appleby  Pooley Bridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441769, 'South Molton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441770, 'Brodick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441771, 'Maud', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441772, 'Preston', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441773, 'Ripley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441775, 'Spalding', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441776, 'Stranraer', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441777, 'Retford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441778, 'Bourne', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441779, 'Peterhead', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441780, 'Stamford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441782, 'Stoke-on-Trent', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441784, 'Iver', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441785, 'Stafford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441786, 'Stirling', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441787, 'Sudbury', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441788, 'Rugby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441789, 'Stratford-upon-Avon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441790, 'Spilsby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441792, 'Swansea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441793, 'Swindon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441794, 'Romsey', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441795, 'Sittingbourne', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441796, 'Pitlochry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441797, 'Rye', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441798, 'Pulborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441799, 'Saffron Walden', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441803, 'Torquay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441805, 'Torrington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441806, 'Voe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441807, 'Ballindalloch', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441808, 'Tomatin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441809, 'Tomdoun', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441821, 'Coupar Angus', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441822, 'Tavistock', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441823, 'Taunton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441824, 'Ruthin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441825, 'Uckfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441827, 'Tamworth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441828, 'Coupar Angus', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441829, 'Tarporley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441830, 'Kirkwhelpington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441832, 'Clopton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441833, 'Barnard Castle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441834, 'Narberth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441835, 'St Boswells', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441837, 'Okehampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441838, 'Dalmally', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441840, 'Camelford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441841, 'Newquay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441842, 'Thetford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441843, 'Thanet', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441844, 'Thame', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441845, 'Thirsk', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441847, 'Thurso & Tongue', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441848, 'Thornhill', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441851, 'Great Bernera & Stornoway', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441852, 'Kilmelford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441854, 'Ullapool', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441855, 'Ballachulish', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441856, 'Kirkwall', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441857, 'Sanday', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441858, 'Market Harborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441859, 'Harris', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441862, 'Tain', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441863, 'Ardgay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441864, 'Abington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441865, 'Oxford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441866, 'Kilchrenan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441869, 'Bicester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441870, 'Benbecula', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441871, 'Castlebay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441872, 'Truro', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441873, 'Abergavenny', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441874, 'Brecon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441875, 'Tranent', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441876, 'Lochmaddy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441877, 'Trossachs', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441878, 'Lohboisdale', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441879, 'Scarinish', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441880, 'Tarbert', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441882, 'Kinloch Rannoch', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441883, 'Merstham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441884, 'Tiverton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441885, 'Bromyard', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441886, 'Bromyard', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441887, 'Aberfeldy', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441888, 'Turriff', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441889, 'Dapple Heath', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441890, 'Coldstream & Ayton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441892, 'Tunbridge Wells', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441895, 'Iver', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441896, 'Galashiels', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441899, 'Biggar', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441900, 'Workington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441902, 'Wolverhampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441903, 'Worthing', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441904, 'York', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441905, 'Worcester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441908, 'Wolverton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441909, 'Worksop', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441920, 'Knebworth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441922, 'Wolverhampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441923, 'Watford', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441924, 'Wakefield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441925, 'Warrington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441926, 'Leamington Spa', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441928, 'Frodsham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441929, 'Wareham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441931, 'Shap', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441932, 'Esher', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441933, 'Wellingborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441934, 'Weston-Super-Mare', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441935, 'Yeovil', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441937, 'Wetherby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441938, 'Welshpool', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441939, 'Wem', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441942, 'Wigan', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441943, 'Guiseley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441944, 'West Heslerton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441945, 'Wisbech', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441946, 'Whitehaven & Gosforth (Mixed)', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441947, 'Whitby', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441948, 'Whitchurch', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441949, 'Whatton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441950, 'Sandwick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441951, 'Colonsay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441952, 'Wellington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441953, 'Attleborough', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441954, 'Madingley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441955, 'Wick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441957, 'Mid Yell', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441959, 'Swanley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441960, 'Formerly Ballyclare', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441962, 'Winchester', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441963, 'Templecombe', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441964, 'Hornsea & Patrington', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441967, 'Strontian', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441968, 'Penicuik', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441969, 'Leyburn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441970, 'Aberystwyth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441971, 'Scourie', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441972, 'Glenborrodale', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441974, 'Llanon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441975, 'Alford & Strathdon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441977, 'Pontefract', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441978, 'Wrexham', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441980, 'Bulford Camp', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441981, 'Wormbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441982, 'Builth Wells', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441983, 'Ryde', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441984, 'Stogumber', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441985, 'Warminster', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441986, 'Bungay', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441987, 'Ebbsfleet', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441988, 'Wigtown', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441989, 'Ross-on-Wye', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441992, 'Hoddesdon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441993, 'Witney', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441994, 'St Clears', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441995, 'Garstang', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(441997, 'Strathpeffer', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442310, 'Portsmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442311, 'Southampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442380, 'Southampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442381, 'Southampton', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442392, 'Portsmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442393, 'Portsmouth', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442410, 'Coventry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442476, 'Coventry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442477, 'Coventry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442810, 'Belfast', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442820, 'Ballycastle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442821, 'Martinstown', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442825, 'Ballymena', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442827, 'Ballymoney', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442828, 'Larne', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442829, 'Kilrea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442830, 'Newry', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442837, 'Armagh', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442838, 'Portadown', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442840, 'Banbridge', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442841, 'Rostrevor', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442842, 'Kircubbin', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442843, 'Newcastle', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442844, 'Downpatrick', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442866, 'Enniskillen', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442867, 'Lisnaskea', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442868, 'Kesh', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442870, 'Coleraine', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442871, 'Londonderry', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442877, 'Limavady', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442879, 'Magherafelt', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442880, 'Carrickmore', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442881, 'Newtownstewart', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442882, 'Omagh', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442885, 'Ballygawley', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442886, 'Cookstown', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442887, 'Dungannon', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442889, 'Fivemiletown', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442890, 'Belfast City', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442891, 'Bangor', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442892, 'Lisburn', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442893, 'Ballyclare', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442894, 'Antrim', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442895, 'Belfast', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442897, 'Saintfield', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442920, 'Cardiff', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(442921, 'Cardiff', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447000, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447001, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447002, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447004, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447007, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447009, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447020, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447074, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447091, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447504, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447505, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447506, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447507, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447508, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447512, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447513, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447514, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447515, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447516, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447517, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447518, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447519, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447521, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447522, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447523, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447525, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447526, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447533, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447588, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447600, 'UK Paging', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447624, 'UK MBL Manx Telecom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447699, 'UK Paging', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447701, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447702, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447703, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447704, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447705, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447706, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447707, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447708, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447709, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447710, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447711, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447712, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447713, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447714, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447715, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447716, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447717, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447718, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447719, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447720, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447721, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447722, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447723, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447724, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447725, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447726, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447727, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447728, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447729, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447730, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447731, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447732, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447733, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447734, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447735, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447736, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447737, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447738, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447739, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447740, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447741, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447742, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447743, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447745, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447746, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447747, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447748, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447749, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447750, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447751, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447752, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447753, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447754, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447756, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447757, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447758, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447759, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447760, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447761, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447762, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447763, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447764, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447765, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447766, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447767, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447768, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447769, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447770, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447771, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447772, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447773, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447774, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447775, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447776, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447777, 'UK MBL BT Fusion', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447778, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447779, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447780, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447781, 'Guernsey Mobile', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447782, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447783, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447784, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447785, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447786, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447787, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447788, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447789, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447790, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447791, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447792, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447793, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447794, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447795, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447796, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447798, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447799, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447800, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447801, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447802, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447803, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447804, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447805, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447806, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447807, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447808, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447809, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447810, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447811, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447812, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447813, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447814, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447815, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447816, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447817, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447818, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447819, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447820, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447821, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447822, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447823, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447824, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447825, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447826, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447827, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447828, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447830, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447831, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447832, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447833, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447834, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447835, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447836, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447837, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447838, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447840, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447841, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447842, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447843, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447844, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447845, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447846, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447847, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447848, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447849, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447850, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447851, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447852, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447853, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447854, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447855, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447856, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447857, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447858, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447859, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447860, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447861, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447862, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447863, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447865, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447866, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447867, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447868, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447869, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447870, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447871, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447875, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447876, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447877, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447878, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447879, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447880, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447881, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447882, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447883, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447884, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447885, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447886, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447887, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447888, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447889, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447890, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447891, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447894, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447895, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447896, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447897, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447898, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447899, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447900, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447901, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447902, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447903, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447904, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447905, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447906, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447907, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447908, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447909, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447910, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447912, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447913, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447914, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447915, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447916, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447917, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447918, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447919, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447920, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447921, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447922, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447923, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447925, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447926, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447927, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447928, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447929, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447930, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447931, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447932, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447933, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447934, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447935, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447936, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447937, 'UK MBL Jersey Telecom f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447938, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447939, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447940, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447941, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447942, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447943, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447944, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447945, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447946, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447947, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447948, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447949, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447950, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447951, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447952, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447953, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447954, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447955, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447956, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447957, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447958, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447959, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447960, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447961, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447962, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447963, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447964, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447965, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447966, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447967, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447968, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447969, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447970, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447971, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447972, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447973, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447974, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447975, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447976, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447977, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447979, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447980, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447981, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447982, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447983, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447984, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447985, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447986, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447987, 'UK MBL T-Mobile', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447988, 'UK MBL (3)', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447989, 'UK MBL Orange', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447990, 'UK MBL Vodafone', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447997, 'Mcom MNP Test', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447999, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454260, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454270, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454276, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454277, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454278, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454279, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454280, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454281, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454282, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454283, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454284, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454285, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454286, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454287, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454288, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454289, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454290, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454291, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454292, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454293, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454294, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454295, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454296, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454297, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454298, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(454299, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455210, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455211, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455212, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455213, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455214, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455215, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455216, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455217, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455218, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455219, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455220, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455221, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455222, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455223, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455224, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455225, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455226, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455227, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455228, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455229, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455230, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455231, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455232, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455233, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455234, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455235, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455236, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455237, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455238, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455239, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455240, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455241, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455242, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455243, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455244, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455245, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455246, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455247, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455249, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455250, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455252, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455253, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455255, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455258, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455260, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455261, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455262, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455263, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455264, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455265, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455266, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455267, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455268, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455269, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455270, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455271, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455272, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455273, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455274, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455275, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455276, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455277, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455278, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455279, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455280, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455281, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455282, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455288, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455290, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455292, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455299, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455310, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455311, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455312, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455313, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455314, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455315, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455316, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455317, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455318, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455319, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455330, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455331, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455332, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455333, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455334, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455335, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455336, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455337, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455338, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(455339, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457115, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457116, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457117, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457118, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457119, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457120, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457121, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457122, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457123, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457124, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457171, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457177, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457191, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(457192, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(458111, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(458181, 'Denmark Mobile', 58, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467014, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467190, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467215, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467216, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467217, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467218, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467219, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467220, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467221, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467222, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467223, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467224, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467300, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467302, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467303, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467304, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467305, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467306, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467307, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467308, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467309, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467320, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467323, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467340, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467341, 'lenor', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467342, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467343, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467344, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467350, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467351, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467352, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467353, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467354, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467380, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467381, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467382, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467383, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467384, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467385, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467388, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467600, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467610, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467611, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467612, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467613, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467614, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467616, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467617, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467618, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467619, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467630, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467631, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467632, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467633, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467634, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467639, 'Sweden Mobile Hi3G', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467660, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467661, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467662, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467663, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467664, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467677, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467678, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467679, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467680, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467681, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467682, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467683, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467684, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467685, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467686, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467687, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467688, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(467689, 'Sweden Mobile Telenor', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487271, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487272, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487273, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487274, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487275, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487276, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487277, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487278, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487279, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487280, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487281, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487282, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487283, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487284, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487285, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487286, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487287, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487288, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487289, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487290, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487291, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487860, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487861, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487862, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487863, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487864, 'Poland Mobile Other', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487865, 'Poland Mobile Orange', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487866, 'Poland Mobile Orange', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487867, 'Poland Mobile Orange', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487868, 'Poland Mobile Orange', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(487869, 'Poland Mobile Orange', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488811, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488818, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488830, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488831, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488832, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488833, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488834, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488835, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488836, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488837, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488838, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(488839, 'Poland Mobile', 171, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491511, 'Germany T-Mobile Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491512, 'Germany T-Mobile Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491514, 'Germany T-Mobile Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491515, 'Germany T-Mobile Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491520, 'Germany Vodafone Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491522, 'Germany Vodafone Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491525, 'Germany Vodafone Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491575, 'Germany E-Plus Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491577, 'Germany E-Plus Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(491578, 'Germany E-Plus Mobile', 80, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504881, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504882, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504883, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504884, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504885, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504886, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504887, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504888, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504889, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504890, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504891, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504892, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504893, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504894, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504895, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504896, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504897, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504898, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(504899, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507120, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507161, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507218, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507219, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507272, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507276, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507443, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507810, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507811, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507836, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507855, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507872, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(507873, 'Panama Mobile', 165, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509210, 'Haiti Port au Prince', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509561, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509562, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509563, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509564, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(509565, 'Haiti Mobile', 93, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537750, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537751, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537752, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537753, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537754, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537755, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537756, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(537758, 'Cuba Mobile', 55, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551081, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551276, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551278, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551281, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551282, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551283, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551284, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551285, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551286, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551287, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551289, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551376, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551381, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551382, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551383, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551384, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551386, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551387, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551389, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551476, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551481, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551482, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551483, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551484, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551486, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551487, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551489, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551576, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551581, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551582, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551583, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551584, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551585, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551586, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551587, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551589, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551681, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551682, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551683, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551684, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551685, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551686, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551687, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551689, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551781, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551782, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551783, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551784, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551786, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551787, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551789, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551876, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551878, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551881, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551882, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551883, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551884, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551885, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551886, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551887, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551889, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551976, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(551978, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552278, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552778, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552781, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552789, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552878, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552881, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552882, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552883, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552885, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552886, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552887, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(552888, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553178, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553278, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553284, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553285, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553286, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553287, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553288, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553384, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553386, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553387, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553388, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553484, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553486, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553487, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553488, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553584, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553585, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553586, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553587, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553588, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553778, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553784, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553786, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553787, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553878, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553884, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553885, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553886, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553887, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(553888, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554170, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554178, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554184, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554185, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554188, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554284, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554285, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554288, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554381, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554384, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554388, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554484, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554488, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554584, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554585, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554588, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554678, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554684, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554685, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554688, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554784, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554881, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554884, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554885, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554888, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554978, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554984, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554985, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(554988, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555178, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555381, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555382, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555384, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555389, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555481, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555482, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555484, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555489, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555581, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555582, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555584, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555585, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(555589, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556081, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556089, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556178, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556181, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556182, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556184, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556185, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556189, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556381, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556382, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556384, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556389, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556481, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556482, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556484, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556489, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556678, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556681, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556682, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556684, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556685, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556688, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556689, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556778, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556781, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556782, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556784, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556789, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556878, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556978, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556981, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556982, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556984, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556985, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556988, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(556989, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557178, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557378, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557381, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557382, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557386, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557387, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557388, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557478, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557481, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557482, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557486, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557487, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557488, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557578, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557581, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557582, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557585, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557586, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557587, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557588, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557778, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557781, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557782, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557786, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557787, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557978, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557981, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557982, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557985, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557986, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557987, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(557988, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558088, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558285, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558286, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558287, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558288, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558388, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558685, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558686, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558687, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558688, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558786, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558787, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558885, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558886, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558887, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558888, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558985, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558986, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558987, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(558988, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559088, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559181, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559188, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559189, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559381, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559382, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559383, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559385, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559386, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559387, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559388, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559389, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559481, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559482, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559483, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559485, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559486, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559487, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559488, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559489, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559581, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559588, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559589, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559681, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559688, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559689, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559781, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559782, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559783, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559785, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559786, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559787, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559788, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559881, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559882, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559883, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559885, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559886, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559887, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559888, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559889, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559981, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559988, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(559989, 'Brazil Mobile', 30, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(562196, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(562197, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(562198, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563019, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563119, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563210, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563255, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563319, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563419, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563519, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563619, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563719, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563819, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(563919, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564019, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564119, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564219, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564319, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564419, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564519, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564619, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564719, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564819, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(564919, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565019, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565119, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565219, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565319, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565419, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565519, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565619, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565719, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565819, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(565919, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566019, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566119, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566219, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566319, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566419, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566519, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566619, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566719, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566819, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(566919, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567019, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567119, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567219, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567319, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567419, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567519, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567619, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567719, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567819, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(567919, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(575420, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(575421, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(575422, 'Colombia Baranguilla', 47, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(590690, 'Guadeloupe Mobile', NULL, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592214, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592224, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592248, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592278, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592284, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592294, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592304, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592374, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592384, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592394, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592600, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592601, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592602, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592603, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592604, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592609, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592610, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592611, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592612, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592613, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592614, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592616, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592617, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592630, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592633, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592634, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592635, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592638, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592639, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592650, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592651, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592652, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592653, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592654, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592655, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592656, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592657, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592658, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(592800, 'Guyana Mobile', 91, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(593803, 'Ecuador Pager', 62, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(594694, 'French Guiana Mobile', 74, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595941, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595943, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595945, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595961, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595971, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595973, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595975, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595981, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595982, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595983, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595985, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595991, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595993, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(595995, 'Paraguay Mobile', 167, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(596696, 'Martinique Mobile', 134, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599318, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599416, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599510, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599511, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599520, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599521, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599522, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599523, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599524, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599525, 'Netherlands Antilles St Maarten', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599526, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599527, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599530, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599531, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599550, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599551, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599552, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599553, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599554, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599555, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599556, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599557, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599558, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599559, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599580, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599581, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599582, 'Netherlands Antilles St Maarten', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599583, 'Netherlands Antilles St Maarten', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599586, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599587, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599588, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599589, 'Netherlands Antilles St Maarten', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599700, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599701, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599951, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599952, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599954, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599955, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599956, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599961, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599966, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599967, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(599969, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611801, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611802, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611803, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611804, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611805, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611806, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611807, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611808, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(611809, 'Australia Mobile', 13, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(674555, 'Nauru Mobile', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(674556, 'Nauru Mobile', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(674557, 'Nauru Mobile', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(674558, 'Nauru Mobile', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(674559, 'Nauru Mobile', 148, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675115, 'Papua New Guinea Mobile VM', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675733, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675734, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675736, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675738, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(675739, 'Papua New Guinea Mobile', 166, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(677671, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(677672, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(677673, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(677674, 'Solomon Islands Mobile', 194, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680620, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680630, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680640, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680660, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680680, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680690, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680775, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(680779, 'Palau Mobile', 163, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(692455, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(692456, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730130, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730131, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730132, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730133, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730134, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730135, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730136, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730137, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730138, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730139, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730140, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730141, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730142, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730143, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730144, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730145, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730146, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730148, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(730149, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734240, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734241, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734242, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734243, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734244, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734245, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734246, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734248, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734249, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734250, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734251, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734252, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734253, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734254, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734255, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734256, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734257, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734258, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734259, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734260, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734261, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734262, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734265, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734266, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734268, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734269, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734271, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734272, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734273, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734274, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734275, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734276, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734277, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734278, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734279, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734291, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734292, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734293, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734294, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734296, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734297, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734298, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734348, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734922, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734932, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734934, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734938, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734940, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734948, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734992, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734993, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734994, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734995, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734996, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(734997, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735230, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735231, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735232, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735233, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735234, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735235, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735236, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735237, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735238, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735239, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735240, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735241, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735242, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735243, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735244, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735245, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735247, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735248, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735249, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735251, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735252, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735253, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735256, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(735257, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738141, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738150, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738151, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738152, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738153, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738154, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738155, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738156, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738157, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738158, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738159, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738160, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738161, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738162, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738163, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738164, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738165, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738166, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738167, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738168, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738169, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738170, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738171, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738172, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738173, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738174, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738175, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738176, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738177, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738178, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738179, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738259, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738340, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738341, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738343, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738345, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738346, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738347, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738348, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738349, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738350, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738351, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738352, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738353, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738354, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738355, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738356, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738357, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738358, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738359, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738360, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738361, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738362, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738363, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738364, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738365, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738366, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738367, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738368, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738369, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738371, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738372, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738373, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738441, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738442, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738443, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738444, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738445, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738446, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738447, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738448, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738449, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738451, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738452, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738453, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738454, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738455, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738456, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738459, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738471, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738473, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738474, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738475, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738510, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738511, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738512, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738513, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738514, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738515, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738516, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738517, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738518, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738519, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738530, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738531, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738532, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738533, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738534, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738535, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738536, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738537, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738538, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738539, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738550, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738551, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738552, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738553, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738554, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738555, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738556, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738557, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738558, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738559, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738560, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738561, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738562, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738563, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738564, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738565, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738566, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738567, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738568, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738569, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738570, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738571, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738572, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738573, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738574, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738575, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738576, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738577, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738578, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738579, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738590, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738591, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738592, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738593, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738594, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738595, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738596, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738597, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738598, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738599, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(738844, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(741656, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742135, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742137, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742138, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742141, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742142, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742144, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742146, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742149, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742151, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742153, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742154, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742155, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742156, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742171, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742331, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742334, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742335, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742337, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742339, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742351, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742352, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742354, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742355, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742356, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742357, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742359, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742371, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742372, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742373, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742374, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742375, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742376, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(742377, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771290, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771291, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771390, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771391, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771490, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771491, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771590, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771591, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771790, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771791, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771890, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(771891, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772190, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772191, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772390, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772391, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772490, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772491, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772590, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772591, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772690, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772691, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772790, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(772791, 'Kazakhstan Mobile', 109, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782130, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782131, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782132, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782133, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782134, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782135, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782136, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782137, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782138, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782139, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782140, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782141, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782142, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782144, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782145, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782146, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782147, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782149, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(782151, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(905338, 'Cyprus (North) Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(905428, 'Cyprus (North) Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918000, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918001, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918002, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918003, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918004, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918006, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918007, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918008, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918009, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918010, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918011, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918012, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918013, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918014, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918015, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918016, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918017, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918018, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918019, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918050, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918051, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918052, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918053, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918054, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918055, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918056, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918057, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918058, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918059, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918080, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918081, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918082, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918083, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918084, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918085, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918086, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918087, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918088, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918089, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918092, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918093, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918094, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918095, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918097, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918099, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918100, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918101, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918102, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918103, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918104, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918105, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918106, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918107, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918108, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918109, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918120, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918121, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918122, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918123, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918124, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918125, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918126, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918127, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918128, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918129, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918140, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918141, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918142, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918143, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918144, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918145, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918146, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918147, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918148, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918149, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918800, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918801, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918802, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918803, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918804, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918805, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918806, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918807, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918808, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918809, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918870, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918871, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918873, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918874, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918875, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918876, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918877, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918878, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918890, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918891, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918892, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918893, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918894, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918896, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918897, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918898, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918899, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918905, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918906, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918907, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918908, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918909, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918950, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918954, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918955, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918956, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918957, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918958, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918959, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918970, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918972, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918975, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918976, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(918977, 'India Mobile', 99, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(962785, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(962786, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(962788, 'Jordan Mobile', 108, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965500, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965501, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965502, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965505, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965506, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965507, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965508, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965509, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965550, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965554, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965555, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965556, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965557, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965558, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965559, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965570, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965578, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965579, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965701, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965702, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965703, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965704, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965705, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965706, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965707, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965708, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965709, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965770, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965771, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965772, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965773, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965774, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965775, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965776, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965778, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(965779, 'Kuwait Mobile', 114, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(968930, 'Oman Mobile', 161, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(972151, 'Israel Mobile', 104, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(972153, 'Israel Mobile', 104, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(992501, 'Tajikistan Mobile', 208, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(993122, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996312, 'Kyrgyzstan Bishkek', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996315, 'Kyrgyzstan Bishkek', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996502, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996503, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996515, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996517, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996543, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996545, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996550, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996555, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996575, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996577, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(996700, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998711, 'Uzbekistan Tashkent', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998712, 'Uzbekistan Tashkent', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998713, 'Uzbekistan Tashkent', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998714, 'Uzbekistan Tashkent', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998735, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242357, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242359, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242375, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242395, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242422, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242423, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242424, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242425, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242426, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242427, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242431, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242432, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242434, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242436, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242441, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242442, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242452, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242454, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242455, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242456, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242457, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242464, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242465, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242466, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242467, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242468, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242471, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242472, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242475, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242477, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242524, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242525, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242533, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242535, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242544, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242551, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242552, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242553, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242554, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242556, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242557, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242558, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242559, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242565, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242577, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242636, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242646, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1242727, 'Bahamas Mobile', 16, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246446, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246447, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246448, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246449, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246820, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246821, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246822, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246823, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246824, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246825, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246826, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246827, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246828, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1246829, 'Barbados Mobile', 19, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264235, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264469, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264476, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264536, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264537, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264538, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264539, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264581, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264582, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264583, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264584, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264724, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264729, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1264772, 'Anguilla Mobile', 7, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268406, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268409, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268464, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268720, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268721, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268722, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268723, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268724, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268725, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268726, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268727, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268728, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268729, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268732, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268764, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268770, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268771, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268772, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268773, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268774, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268775, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268776, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268779, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268780, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268781, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268782, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268783, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268784, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268785, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268786, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1268788, 'Antigua and Barbuda Mobile', 9, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284300, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284301, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284302, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284303, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284342, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284440, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284441, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284442, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284443, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284444, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284445, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284446, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284468, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284499, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284540, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284541, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284542, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284543, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1284544, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340201, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340226, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340227, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340244, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340277, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340332, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340344, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340473, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340474, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340513, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340514, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340626, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340642, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340643, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340677, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340690, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340727, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340771, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340884, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1340998, 'US Virgin Islands Mobile', 233, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345229, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345321, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345322, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345323, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345324, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345325, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345326, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345327, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345328, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345329, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345514, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345516, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345517, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345525, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345526, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345527, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345545, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345546, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345547, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345548, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345549, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345916, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345917, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345919, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345924, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345925, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345926, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345927, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345928, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345929, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345930, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345938, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1345939, 'Cayman Islands Mobile', 40, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1441590, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1441599, 'Bermuda Mobile', 24, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473403, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473404, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473405, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473406, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473407, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473409, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473410, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473414, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473415, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473416, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473417, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473418, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473419, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473420, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473456, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473457, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473458, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473459, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473533, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473534, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473535, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473536, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473537, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1473538, 'Grenada Mobile', 85, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649231, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649232, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649241, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649242, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649243, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649244, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649245, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649246, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649247, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649249, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649331, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649332, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649333, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649339, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649341, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649342, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649343, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649344, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649345, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649346, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649431, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649432, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649441, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649442, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1649724, 'Turks and Caicos Mobile', 219, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1664492, 'Montserrat Mobile', 143, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1664493, 'Montserrat Mobile', 143, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1664496, 'Montserrat Mobile', 143, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1664724, 'Montserrat Mobile', 143, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670285, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670286, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670287, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670483, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670484, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670488, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670588, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670788, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670789, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670838, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670848, 'Northern Mariana Islands Mobile', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670858, 'Northern Mariana Islands Mobile', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670868, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670878, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670888, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670898, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1670989, 'Northern Mariana Islands Mobil', 159, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1671476, 'Guam Mobile', 87, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1684252, 'American Samoa Mobile', 4, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1684254, 'American Samoa Mobile', 4, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1684258, 'American Samoa Mobile', 4, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1684733, 'American Samoa Mobile', 4, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758284, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758285, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758286, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758287, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758384, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758460, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758461, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758481, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758482, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758483, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758484, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758485, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758486, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758487, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758488, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758489, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758518, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758519, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758520, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758584, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758712, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758713, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758714, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758715, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758716, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758717, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758718, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758719, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758720, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758721, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758722, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758723, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1758724, 'St Lucia Mobile', 181, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767225, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767235, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767245, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767265, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767275, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767276, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767277, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767315, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767316, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767317, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767611, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767612, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767613, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767614, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767615, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767616, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1767617, 'Dominica Mobile', 60, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784430, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784431, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784432, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784433, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784434, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784454, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784455, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784492, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784493, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784494, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784495, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784526, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784527, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784528, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784529, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784530, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784531, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784532, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784533, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1784593, 'St Vincent and the Grenadines', 183, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787201, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787202, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787203, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787204, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787205, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787206, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787207, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787208, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787209, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787210, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787212, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787213, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787214, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787215, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787216, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787217, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787218, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787219, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787220, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787221, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787222, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787223, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787224, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787225, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787226, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787228, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787230, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787231, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787232, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787233, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787234, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787235, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787236, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787237, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787238, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787239, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787240, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787241, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787242, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787243, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787244, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787245, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787246, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787247, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787248, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787249, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787295, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787297, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787298, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787299, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787301, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787302, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787303, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787304, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787305, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787306, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787307, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787308, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787309, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787310, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787311, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787312, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787313, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787314, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787315, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787316, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787317, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787318, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787319, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787320, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787321, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787322, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787323, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787324, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787325, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787326, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787327, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787328, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787329, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787330, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787331, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787332, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787333, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787334, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787335, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787336, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787337, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787338, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787339, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787340, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787341, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787342, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787343, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787344, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787345, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787346, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787347, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787348, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787349, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787350, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787351, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787352, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787353, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787354, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787355, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787356, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787357, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787358, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787359, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787360, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787361, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787362, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787363, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787364, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787365, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787366, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787367, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787368, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787369, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787370, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787371, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787372, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787373, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787374, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787375, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787376, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787377, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787378, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787379, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787380, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787381, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787382, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787383, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787384, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787385, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787386, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787387, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787388, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787389, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787390, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787391, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787392, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787393, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787394, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787396, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787397, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787398, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787399, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787400, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787401, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787402, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787403, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787404, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787405, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787406, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787407, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787408, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787409, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787410, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787411, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787412, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787413, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787414, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787415, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787416, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787417, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787418, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787419, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787420, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787421, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787422, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787423, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787424, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787425, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787426, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787427, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787428, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787429, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787430, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787431, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787432, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787433, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787434, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787435, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787436, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787438, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787439, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787440, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787441, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787442, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787443, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787444, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787445, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787446, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787447, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787448, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787449, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787450, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787451, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787452, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787453, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787454, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787455, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787456, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787457, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787458, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787459, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787460, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787461, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787462, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787463, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787464, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787465, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787466, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787467, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787469, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787470, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787471, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787472, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787473, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787474, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787475, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787477, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787478, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787479, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787481, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787484, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787485, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787486, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787487, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787488, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787489, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787490, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787491, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787492, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787493, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787494, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787495, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787496, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787497, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787498, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787499, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787501, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787502, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787503, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787504, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787505, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787506, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787507, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787508, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787509, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787510, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787511, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787512, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787513, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787514, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787515, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787516, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787517, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787518, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787519, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787524, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787525, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787526, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787527, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787528, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787529, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787530, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787531, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787532, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787533, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787534, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787535, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787536, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787537, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787538, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787539, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787540, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787541, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787542, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787543, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787544, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787545, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787546, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787547, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787548, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787549, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787550, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787552, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787553, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787554, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787556, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787557, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787558, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787559, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787560, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787562, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787564, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787565, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787566, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787567, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787568, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787570, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787571, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787572, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787573, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787574, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787575, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787576, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787577, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787578, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787579, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787580, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787581, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787582, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787583, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787584, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787585, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787586, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787587, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787588, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787589, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787590, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787593, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787594, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787595, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787596, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787597, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787598, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787599, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787601, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787602, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787603, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787604, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787605, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787606, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787607, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787608, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787609, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787610, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787611, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787612, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787613, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787614, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787615, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787616, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787617, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787618, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787619, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787624, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787627, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787628, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787629, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787630, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787631, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787632, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787633, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787634, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787635, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787636, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787637, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787638, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787639, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787640, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787641, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787642, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787643, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787644, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787645, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787646, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787647, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787648, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787649, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787661, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787662, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787664, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787666, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787667, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787668, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787669, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787671, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787672, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787673, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787674, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787675, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787676, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787677, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787678, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787685, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787688, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787689, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787690, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787691, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787692, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787696, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787697, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787698, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787702, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787709, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787717, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787718, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787800, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787810, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787900, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787901, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787902, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787903, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787904, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787905, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787906, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787907, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787908, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787909, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787910, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787913, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787914, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787918, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787920, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787921, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787922, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787923, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787925, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787929, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787930, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787932, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787934, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787938, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787940, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787941, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787942, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787943, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787944, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787946, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787948, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787949, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787951, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787955, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787960, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787962, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787963, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787964, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787967, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787968, 'Puerto Rico - Not Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787969, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787972, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787974, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787975, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787979, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787983, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787985, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787987, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787988, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787989, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787990, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787994, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1787996, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809201, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809203, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809204, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809205, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809206, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809207, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809208, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809209, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809210, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809212, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809214, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809215, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809216, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809217, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809218, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809219, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809223, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809224, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809225, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809228, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809229, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809230, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809232, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809235, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809249, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809250, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809251, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809252, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809253, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809254, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809256, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809257, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809258, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809259, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809260, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809264, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809266, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809267, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809268, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809269, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809270, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809271, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809272, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809280, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809281, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809282, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809283, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809284, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809292, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809293, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809297, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809298, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809299, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809301, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809302, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809303, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809304, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809305, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809306, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809307, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809308, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809309, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809310, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809313, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809315, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809316, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809317, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809318, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809319, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809321, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809322, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809323, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809324, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809325, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809326, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809327, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809330, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809340, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809341, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809342, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809343, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809344, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809345, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809348, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809350, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809351, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809352, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809353, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809354, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809355, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809356, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809357, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809358, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809359, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809360, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809361, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809366, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809368, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809369, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809370, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809371, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809373, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809374, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809376, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809377, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809383, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809386, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809387, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809389, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809390, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809391, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809392, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809393, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809394, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809395, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809396, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809397, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809398, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809399, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809401, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809402, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809403, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809404, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809405, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809406, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809407, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809408, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809409, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809410, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809413, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809415, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809416, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809417, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809418, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809419, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809420, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809421, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809423, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809424, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809425, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809426, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809427, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809428, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809429, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809430, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809431, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809432, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809433, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809434, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809436, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809437, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809438, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809439, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809440, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809441, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809442, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809443, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809444, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809445, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809446, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809447, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809448, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809449, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809451, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809452, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809453, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809454, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809456, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809457, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809458, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809459, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809460, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809461, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809462, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809463, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809464, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809465, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809467, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809474, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809475, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809477, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809478, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809479, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809480, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809481, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809484, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809485, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809486, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809488, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809490, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809491, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809492, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809493, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809494, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809495, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809496, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809497, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809498, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809499, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809501, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809502, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809504, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809505, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809506, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809507, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809509, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809510, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809512, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809513, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809514, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809515, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809516, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809517, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809519, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809520, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809543, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809546, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809547, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809555, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809601, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809602, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809603, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809604, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809605, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809606, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809607, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809608, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809609, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809610, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809613, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809614, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809615, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809617, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809618, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809619, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809624, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809627, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809628, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809629, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809630, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809631, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809632, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809634, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809635, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809636, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809637, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809639, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809640, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809641, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809642, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809643, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809644, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809645, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809646, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809647, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809648, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809649, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809650, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809651, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809652, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809653, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809654, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809656, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809657, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809658, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809659, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809660, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809661, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809662, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809663, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809664, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809665, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809666, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809667, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809668, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809669, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809670, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809671, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809672, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809673, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809674, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809675, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809676, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809677, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809678, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809693, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809694, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809696, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809697, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809698, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809702, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809703, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809704, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809705, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809706, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809707, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809708, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809709, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809710, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809712, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809713, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809714, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809715, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809716, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809717, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809718, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809719, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809720, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809721, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809722, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809723, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809727, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809729, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809742, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809743, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809747, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809749, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809750, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809751, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809752, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809753, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809754, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809756, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809757, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809758, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809759, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809760, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809761, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809762, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809763, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809764, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809765, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809767, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809768, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809769, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809771, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809772, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809773, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809774, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809775, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809776, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809777, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809778, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809779, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809780, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809781, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809782, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809783, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809785, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809786, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809787, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809789, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809790, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809791, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809796, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809798, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809801, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809802, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809803, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809804, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809805, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809806, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809807, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809808, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809810, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809812, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809814, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809815, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809816, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809817, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809818, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809819, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809820, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809821, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809827, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809828, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809829, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809834, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809835, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809836, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809837, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809838, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809839, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809840, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809841, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809842, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809843, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809844, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809845, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809846, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809847, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809848, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809849, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809850, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809851, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809852, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809853, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809854, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809855, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809856, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809857, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809858, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809860, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809861, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809862, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809863, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809864, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809865, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809866, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809867, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809868, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809869, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809871, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809873, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809874, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809875, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809876, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809877, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809878, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809879, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809880, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809881, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809882, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809883, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809884, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809885, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809886, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809888, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809889, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809890, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809891, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809897, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809899, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809901, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809902, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809903, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809904, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809905, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809906, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809907, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809908, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809909, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809910, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809912, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809913, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809914, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809915, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809916, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809917, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809918, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809919, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809920, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809921, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809922, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809923, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809924, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809928, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809929, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809931, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809932, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809935, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809938, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809939, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809940, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809941, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809942, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809943, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809944, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809945, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809946, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809949, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809951, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809952, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809953, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809954, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809955, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809956, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809957, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809958, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809959, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809960, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809961, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809962, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809963, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809964, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809965, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809966, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809967, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809968, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809969, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809970, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809971, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809972, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809973, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809974, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809975, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809977, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809978, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809979, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809980, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809981, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809982, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809983, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809984, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809986, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809987, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809988, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809989, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809990, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809991, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809992, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809993, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809994, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809995, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809996, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809997, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809998, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1809999, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829201, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829202, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829203, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829204, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829205, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829206, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829207, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829208, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829209, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829210, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829212, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829214, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829215, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829221, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829222, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829223, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829224, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829225, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829230, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829232, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829233, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829246, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829248, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829250, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829252, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829255, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829257, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829258, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829259, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829260, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829261, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829262, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829263, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829264, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829265, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829266, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829267, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829268, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829269, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829270, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829271, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829272, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829273, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829274, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829275, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829276, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829277, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829278, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829279, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829280, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829281, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829282, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829283, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829284, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829285, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829286, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829287, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829288, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829289, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829290, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829291, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829293, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829294, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829295, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829296, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829297, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829298, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829299, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829301, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829302, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829303, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829304, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829305, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829306, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829307, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829308, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829309, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829310, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829312, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829313, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829314, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829315, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829316, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829317, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829318, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829319, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829320, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829321, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829322, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829323, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829328, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829329, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829330, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829331, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829332, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829333, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829334, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829335, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829336, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829337, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829338, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829339, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829340, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829341, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829342, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829343, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829344, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829345, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829346, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829347, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829348, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829349, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829350, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829351, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829352, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829353, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829354, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829355, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829356, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829357, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829358, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829359, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829360, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829361, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829362, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829363, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829364, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829365, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829366, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829367, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829368, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829369, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829370, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829371, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829372, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829373, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829374, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829375, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829376, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829377, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829379, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829380, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829383, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829386, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829387, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829388, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829389, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829390, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829391, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829392, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829393, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829394, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829395, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829396, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829397, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829398, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829399, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829401, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829402, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829403, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829404, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829405, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829406, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829407, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829408, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829409, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829410, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829412, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829413, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829414, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829415, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829416, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829417, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829418, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829419, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829420, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829421, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829422, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829423, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829424, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829425, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829426, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829427, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829428, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829429, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829430, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829431, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829432, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829436, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829437, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829438, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829439, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829440, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829441, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829442, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829443, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829444, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829445, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829446, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829447, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829448, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829449, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829450, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829451, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829452, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829453, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829454, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829455, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829456, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829457, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829458, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829459, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829460, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829461, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829462, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829463, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829464, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829465, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829466, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829467, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829470, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829471, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829472, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829474, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829475, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829477, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829478, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829479, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829491, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829492, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829493, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829494, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829496, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829497, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829498, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829499, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829502, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829504, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829505, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829506, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829508, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829509, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829512, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829513, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829514, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829515, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829517, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829518, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829519, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829531, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829532, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829533, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829534, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829536, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829537, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829539, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829540, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829542, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829543, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829545, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829546, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829548, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829549, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829550, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829551, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829552, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829553, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829554, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829556, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829557, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829558, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829559, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829560, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829561, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829562, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829563, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829564, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829566, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829568, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829569, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829570, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829571, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829572, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829573, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829577, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829580, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829585, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829586, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829599, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829601, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829602, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829603, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829604, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829605, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829606, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829610, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829613, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829616, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829618, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829630, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829633, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829640, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829644, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829646, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829650, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829653, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829654, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829655, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829657, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829660, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829661, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829662, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829663, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829664, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829665, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829667, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829668, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829669, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829670, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829671, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829672, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829673, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829674, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829675, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829676, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829677, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829678, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829686, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829694, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829696, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829697, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829698, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829699, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829701, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829702, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829703, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829704, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829705, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829706, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829707, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829709, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829710, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829712, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829713, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829714, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829715, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829716, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829717, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829718, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829719, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829720, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829721, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829722, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829723, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829725, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829726, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829727, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829728, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829729, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829730, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829731, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829740, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829742, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829743, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829744, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829747, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829749, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829750, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829751, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829752, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829753, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829754, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829755, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829756, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829757, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829758, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829759, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829760, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829766, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829770, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829771, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829772, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829773, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829774, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829775, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829776, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829777, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829778, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829779, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829780, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829781, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829782, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829783, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829784, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829785, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829786, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829787, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829788, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829789, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829790, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829791, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829792, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829793, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829794, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829795, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829796, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829797, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829798, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829799, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829801, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829802, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829803, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829804, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829805, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829806, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829807, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829808, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829810, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829812, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829814, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829815, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829816, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829817, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829818, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829819, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829820, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829821, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829826, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829827, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829828, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829830, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829835, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829836, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829837, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829838, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829839, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829840, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829841, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829842, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829843, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829844, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829845, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829846, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829847, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829848, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829849, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829850, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829851, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829852, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829853, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829854, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829855, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829856, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829857, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829858, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829859, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829860, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829861, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829862, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829863, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829864, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829865, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829866, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829867, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829868, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829869, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829870, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829871, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829873, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829875, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829876, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829877, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829878, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829879, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829880, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829881, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829882, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829883, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829884, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829885, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829886, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829887, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829889, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829890, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829891, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829892, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829894, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829898, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829899, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829901, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829902, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829903, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829904, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829905, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829906, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829907, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829908, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829909, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829910, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829912, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829913, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829914, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829915, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829916, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829917, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829918, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829919, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829920, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829921, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829922, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829923, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829924, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829925, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829926, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829929, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829930, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829931, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829933, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829935, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829939, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829940, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829953, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829954, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829956, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829957, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829958, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829959, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829961, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829962, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829963, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829964, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829965, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829966, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829967, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829968, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829969, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829970, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829972, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829973, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829974, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829975, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829977, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829978, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829979, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829980, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829981, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829982, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829983, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829984, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829985, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829986, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829990, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829991, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829993, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1829994, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868301, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868302, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868303, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868304, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868305, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868306, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868307, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868308, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868309, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868310, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868312, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868313, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868314, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868315, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868316, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868317, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868318, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868319, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868401, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868402, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868403, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868404, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868405, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868406, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868407, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868408, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868409, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868410, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868412, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868413, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868414, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868415, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868416, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868417, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868418, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868419, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868420, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868421, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868619, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868620, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868678, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868701, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868702, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868703, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868704, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868705, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868706, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868707, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868708, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868709, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868710, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868712, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868713, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868714, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868715, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868716, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868717, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868718, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1868719, 'Trinidad and Tobago Mobile', 215, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869556, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869557, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869558, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869565, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869566, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869567, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869660, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869661, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869662, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869663, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869664, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869665, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869667, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869668, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869669, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869762, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869763, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869764, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1869765, 'St Kitts and Nevis Mobile', 180, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876210, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876286, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876287, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876288, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876301, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876302, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876303, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876304, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876305, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876320, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876322, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876410, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876411, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876412, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876413, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876414, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876416, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876417, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876418, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876419, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876490, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876491, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876492, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876493, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876494, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876503, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876504, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876505, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876506, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876507, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876508, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876509, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876520, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876521, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876522, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876524, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876527, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876528, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876529, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876550, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876551, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876552, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876553, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876554, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876556, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876557, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876558, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876559, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876561, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876568, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876569, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876700, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876707, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876781, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876782, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876783, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876784, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876787, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876788, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876789, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876790, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876791, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876792, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876793, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876796, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876797, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876798, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876799, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876801, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876802, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876803, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876804, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876805, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876806, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876807, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876808, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876809, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876909, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876919, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876990, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876995, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876997, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1876999, 'Jamaica Mobile', 106, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939207, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939217, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939218, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939232, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939240, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939241, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939242, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939243, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939244, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939245, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939246, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939247, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939248, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939249, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939250, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939251, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939252, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939253, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939254, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939255, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939325, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939334, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939339, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939350, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939358, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939389, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939397, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939452, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939475, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939579, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939628, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939630, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939639, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939640, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939642, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939644, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939645, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939717, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939732, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939865, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939891, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939940, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(1939969, 'Puerto Rico Mobile', 173, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2125290, 'Morocco Casablanca', 144, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272020, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272031, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272032, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272033, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272034, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272035, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272036, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272037, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272072, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272073, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272074, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2272075, 'Niger Naimey', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2302189, 'Mauritius Mobile', 136, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2332170, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2332260, 'Ghana Mobile', 81, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2341320, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2348190, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2348191, 'Nigeria Mobile', 155, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2511189, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2512289, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2512589, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2513389, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2513489, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2514689, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2514789, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2515789, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2515889, 'Ethiopia Mobile', 68, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(2572955, 'Burundi Mobile', 35, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3364100, 'France [SFR]', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3376000, 'France Mobile', 73, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3567117, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3569811, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3569812, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3569813, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3569897, 'Malta Mobile', 132, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725350, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725351, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725352, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725354, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725355, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725356, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725357, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725358, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3725359, 'Estonia EMT Mobile', 67, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(3906682, 'Vatican City State', 94, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4176777, 'Switzerland Sunrise Mobile', 205, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4455110, 'UK g6 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4455114, 'UK g21 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4455883, 'UK g6 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470030, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470034, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470035, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470036, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470037, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470050, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470051, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470052, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470055, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470058, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470059, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470061, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470063, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470064, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470066, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470081, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470082, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470083, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470085, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470087, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470111, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470113, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470114, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470115, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470116, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470119, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470120, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470121, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470123, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470124, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470126, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470127, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470128, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470129, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470131, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470134, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470137, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470139, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470141, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470143, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470162, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470163, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470164, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470165, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470166, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470168, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470169, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470180, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470182, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470199, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470211, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470216, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470219, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470220, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470221, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470222, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470223, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470231, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470232, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470238, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470239, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470240, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470244, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470245, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470249, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470253, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470255, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470256, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470257, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470259, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470262, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470269, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470273, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470285, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470287, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470288, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470289, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470301, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470303, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470304, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470307, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470309, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470310, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470311, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470312, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470313, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470314, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470316, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470317, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470318, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470319, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470321, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470322, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470323, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470324, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470331, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470332, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470336, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470341, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470342, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470344, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470345, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470350, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470353, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470360, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470361, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470365, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470368, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470390, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470391, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470392, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470393, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470394, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470395, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470396, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470398, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470401, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470404, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470405, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470406, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470407, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470409, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470411, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470412, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470420, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470424, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470426, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470429, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470431, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470432, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470433, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470434, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470435, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470436, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470442, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470443, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470444, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470445, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470446, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470449, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470450, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470451, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470452, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470456, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470461, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470462, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470467, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470469, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470470, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470472, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470477, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470478, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470487, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470490, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470494, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470495, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470497, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470500, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470501, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470502, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470503, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470505, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470506, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470507, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470508, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470509, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470520, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470521, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470522, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470526, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470533, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470535, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470537, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470540, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470544, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470545, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470547, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470557, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470577, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470592, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470593, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470596, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470597, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470598, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470599, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470612, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470613, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470615, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470616, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470618, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470626, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470667, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470694, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470697, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470699, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470703, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470704, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470705, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470707, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470708, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470709, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470710, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470711, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470714, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470715, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470716, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470719, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470750, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470751, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470752, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470754, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470755, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470756, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470757, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470758, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470759, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470761, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470763, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470765, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470766, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470770, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470772, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470773, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470775, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470776, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470777, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470781, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470789, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470790, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470792, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470793, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470794, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470796, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470797, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470803, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470809, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470810, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470812, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470815, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470817, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470819, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470890, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470891, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470897, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470898, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470899, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470901, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470902, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470903, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470904, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470907, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470908, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470909, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470940, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470941, 'UK Personal pn4', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470942, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470946, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470949, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470965, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470966, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470967, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470990, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470992, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470994, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470995, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470996, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470998, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4470999, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4475090, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4475091, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4475092, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476231, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476232, 'UK Paging', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476234, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476237, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476242, 'Guernsey Mobile', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476542, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476543, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476545, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476546, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476593, 'UK Paging', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476596, 'UK Paging', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476599, 'UK Paging', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476637, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476661, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476662, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476663, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476664, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476665, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476667, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4476668, 'UK Paging ff9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477000, 'UK Mobile Wire9 fm6', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477001, 'UK Mobile Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477003, 'Guernsey Mobile', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477007, 'Guernsey Mobile', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477008, 'Guernsey Mobile', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477552, 'UK MBL Inquam f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477553, 'UK MBL Inquam f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477554, 'UK MBL Inquam', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477555, 'UK MBL Inquam', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477977, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477978, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4477979, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478228, 'UK MBL BT Fusion', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478297, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478298, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478299, 'Jersey Mobile', 250, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478398, 'Guernsey Mobile', 248, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478640, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478641, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478642, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478643, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478644, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478645, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478646, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478647, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478648, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478649, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478720, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478721, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478722, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478723, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478724, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478725, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478726, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478727, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478728, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478729, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478730, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478731, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478732, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478733, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478734, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478735, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478736, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478737, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478738, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478739, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478740, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478741, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478742, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478743, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478744, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478745, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478746, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478747, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478748, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478749, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478921, 'UK MBL Mapesbury', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478922, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478923, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478924, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478925, 'UK MBL Other fm2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478926, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478927, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478928, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478929, 'UK MBL O2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4478938, 'UK MBL Telephony Services', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479111, 'UK MBL Wave f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479112, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479117, 'UK MBL Wave f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479118, 'UK MBL Other 24 Seven', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479240, 'UK MBL Manx Telecom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479241, 'UK MBL Manx Telecom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479242, 'UK MBL Manx Telecom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479243, 'UK MBL Manx Telecom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479244, 'UK MBL Manx Telecom', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479245, 'UK MBL Other Wire9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479246, 'UK MBL Other Wire9', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479784, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4479788, 'UK MBL Other', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4484460, 'UK Special g8', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4490630, 'UK PRS p5', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4490632, 'UK PRS p5', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4676760, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4676761, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4676762, 'Sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(4676763, 'sweden Mobile Telia', 204, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5047214, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5047215, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5047217, 'Honduras Mobile', 95, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5632210, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5632255, 'Chile Rural/Easter Island', 43, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5993181, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5993184, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5993185, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5993186, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5994161, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5994165, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5994166, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5994167, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5994168, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5999530, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5999531, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5999630, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(5999631, 'Netherlands Antilles Mobile', 150, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6189100, 'Christmas Island', 45, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6189101, 'Cocos (Keeling) Islands', 46, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6922350, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6922351, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6922352, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6922353, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6922354, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6925451, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6925452, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6925453, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6925454, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6926250, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(6926251, 'Marshall Islands Mobile', 133, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7349363, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(7349364, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9039285, 'Cyprus (North) Mobile', 56, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9721599, 'Israel Mobile', 104, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9741245, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9741744, 'Qatar Mobile', 174, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9932221, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9932431, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9933221, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9934221, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9935221, 'Turkmenistan Mobile', 218, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986135, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986251, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986252, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986530, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986559, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986626, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986637, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986690, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986691, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986692, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986693, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986925, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9986962, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987198, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987257, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987498, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987499, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987520, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987531, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(9987639, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(12844966, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(12844967, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(12844968, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(12844969, 'British Virgin Islands Mobile', 232, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092223, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092224, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092225, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092480, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092482, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092484, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092485, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092486, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092487, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092488, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092651, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092652, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092653, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092654, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092655, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092656, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092657, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092658, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18092659, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094701, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094702, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094703, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094704, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094705, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094706, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094707, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18094708, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18095450, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18095451, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18095454, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18095456, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18095459, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18097421, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18097422, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18098597, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(18098598, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269300, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269301, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269302, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269303, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269304, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269310, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269320, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269330, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269333, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269340, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269350, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269360, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269370, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269380, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269390, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269391, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269392, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269393, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269394, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(26269397, 'Reunion Mobile', 175, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35020054, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35020056, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35020057, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(35020058, 'Gibraltar Mobile', 82, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37165153, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37165158, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(37165159, 'Latvia Mobile', 117, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44551650, 'UK g21 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44551655, 'UK g21 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44551660, 'UK g21 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44551665, 'UK g21 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44555508, 'UK g6 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44555540, 'UK g21 VOIP', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702100, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702101, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702105, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702106, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702140, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702141, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702145, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44702146, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704110, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704111, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704112, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704113, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704114, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704115, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704116, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704117, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704118, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704119, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704620, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704621, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704622, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704623, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704624, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704625, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704626, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704627, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704628, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704629, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704640, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704641, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704642, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704643, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704644, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704645, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704646, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704647, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704648, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44704649, 'UK Personal pn3', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44707090, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44708090, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44708099, 'UK Personal pn2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44800112, 'UK Free', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44844444, 'UK Special g8', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44844604, 'UK Special g6', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44844706, 'UK Special g11', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44844707, 'UK Special g11', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870092, 'UK Special Svcs', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870093, 'UK Special Svcs', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870094, 'UK Special Svcs', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870099, 'UK Special Svcs', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870185, 'UK Special Svcs', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44870188, 'UK Special Svcs', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871327, 'UK Special g7', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871335, 'UK Special g15', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871339, 'UK Special g15', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871737, 'UK Special g14', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871780, 'UK Special g7', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871855, 'UK Special g7', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871856, 'UK Special g14', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(44871859, 'UK Special g14', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73493667, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73493668, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(73493669, 'Russian Federation [FIX2]', 177, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99460540, 'Azerbaijan Mobile', 15, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631270, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631272, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631274, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631275, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631276, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631277, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631278, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99631279, 'Kyrgyzstan Mobile', 115, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861220, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861221, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861298, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861500, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861505, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861506, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861507, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861508, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861509, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861612, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861613, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861740, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99861795, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862211, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862221, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862290, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862291, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862293, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862297, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862299, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862520, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862521, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862522, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862523, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862524, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862525, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862526, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862527, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862528, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862529, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862530, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862560, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862561, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862562, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862563, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862564, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862565, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862566, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862567, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862707, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99862708, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865190, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865191, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865227, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865292, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865296, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865720, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865721, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865722, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865723, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865724, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865730, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865733, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865734, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865735, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865736, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865737, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865775, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99865776, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866215, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866216, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866217, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866218, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866219, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866220, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866223, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866226, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866227, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866238, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866241, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866390, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866391, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866392, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866393, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866399, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866700, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866701, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866702, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866703, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99866704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867224, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867232, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867233, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867237, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867245, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867246, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867247, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867248, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867249, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867275, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867276, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867277, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867278, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867580, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867585, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867587, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867588, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867589, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867700, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867701, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867702, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867703, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867705, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867706, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867707, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867900, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867901, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99867902, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869212, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869216, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869217, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869230, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869231, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869560, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869565, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869570, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869575, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869577, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869680, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869681, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869682, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869683, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869686, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869700, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869701, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869702, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869703, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869705, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99869706, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870345, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870535, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870536, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870537, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870538, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870539, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870604, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99870616, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99871131, 'Uzbekistan [Tashkent]', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99871604, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99871616, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872325, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872326, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872327, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872328, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872329, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872360, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872361, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872362, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872363, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872364, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872365, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872366, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872570, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872575, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872577, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872579, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872706, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872708, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99872709, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873210, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873211, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873212, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873213, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873214, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873215, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873216, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873221, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873234, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873236, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873239, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873271, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873275, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873279, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873330, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873331, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873332, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873333, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873334, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873335, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873336, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873337, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873338, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873500, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873501, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873502, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873503, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873504, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873555, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873557, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873559, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873590, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873591, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873595, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873599, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873700, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873701, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873705, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873707, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873708, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873710, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873711, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873717, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873725, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873727, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873770, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873777, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873779, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873940, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873941, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873944, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873955, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873956, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873959, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873960, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99873966, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874229, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874250, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874255, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874257, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874260, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874261, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874262, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874263, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874264, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874265, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874266, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874267, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874271, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874272, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874273, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874274, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874275, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874277, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874510, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874511, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874580, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874585, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874700, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874701, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874702, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874703, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874705, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874706, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874709, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874775, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874776, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874777, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874778, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874779, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874970, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874971, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874975, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874976, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874977, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874978, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874979, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874980, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874981, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874982, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874983, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874984, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874985, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874986, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874987, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874988, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874989, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874990, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874995, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99874999, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875112, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875222, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875229, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875244, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875294, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875350, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875355, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875360, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875361, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875362, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875363, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875364, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875365, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875366, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875380, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875381, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875382, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875383, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875384, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875385, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875386, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875526, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875527, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875528, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875529, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875760, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875761, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99875767, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876242, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876243, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876244, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876390, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876391, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876392, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876393, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876394, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876395, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876396, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876530, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876531, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876532, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876534, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876535, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876536, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876537, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876538, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876539, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876540, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876541, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876542, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876543, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876544, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876545, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876550, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876551, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876552, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876590, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876591, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876592, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876594, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876595, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876596, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876717, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99876737, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879221, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879228, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879320, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879321, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879322, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879323, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879324, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879370, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879371, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879372, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879373, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879374, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879375, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879376, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879377, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879570, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879575, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879576, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879725, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879726, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879727, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879729, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879740, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879744, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(99879747, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954290, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954291, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954292, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954293, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954295, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954296, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954297, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180954298, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985990, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985991, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985992, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985993, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985994, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985995, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985996, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(180985997, 'Dominican Republic Mobile', 61, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021020, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021021, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021022, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021023, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021024, 'UK Personal nat', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021070, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021071, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021072, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021073, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021074, 'UK Personal d', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021420, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021421, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021422, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021423, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021424, 'UK Personal f', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021470, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021471, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021472, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021473, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(447021474, 'UK Personal k', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(448440970, 'UK Special g2', 224, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998664568, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998664838, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998692700, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998692701, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998692702, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998692703, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998692704, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998706692, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707110, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707111, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707112, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707113, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707114, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707115, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707116, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707133, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707134, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707135, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707136, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707137, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707138, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707139, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707145, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707146, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707149, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707157, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707158, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707159, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707167, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707168, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707169, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707190, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707191, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707192, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998707198, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998716692, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717135, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717136, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717145, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717149, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717157, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717158, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717159, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717167, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717168, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717169, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998717198, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722271, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722272, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722273, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722274, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722275, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722276, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722277, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722278, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722279, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998722295, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762229, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762246, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762247, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762248, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762249, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762257, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762258, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998762259, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764115, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764116, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764117, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764118, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764119, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764171, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764172, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764173, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764174, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764175, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764190, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764191, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764192, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764193, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764194, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764198, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998764199, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998792225, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998792226, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998792227, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998793780, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998795726, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998795727, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998795728, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998795729, 'Uzbekistan Mobile', 228, '', 1);
INSERT INTO `dialcode_prefix` (`prefix`, `destination`, `country_id`, `carrier_name`, `prefix_type`) VALUES(998795790, 'Uzbekistan Mobile', 228, '', 1);
